use master
go
exec sp_configure 'allow updates', 1
reconfigure with override
go
if object_id('helpsql') is null
begin
	create table helpsql(command varchar(30), ordering tinyint, helptext varchar(80))
	create index helpsqli on helpsql(command)
end else exec ('delete helpsql')
GO
declare @name sysname
declare cr cursor for select name from master..sysdatabases
open cr
fetch next from cr into @name
while @@fetch_status=0 begin
	exec ('if object_id('''+@name+'..syskeys'') is null create table '+@name+'..syskeys(id int not null, type smallint not null, depid int null, keycnt int null, size int null, key1 int null,
	key2 int null, key3 int null,  key4 int null, key5 int null, key6 int null, key7 int null, key8 int null, depkey1 int null,
	depkey2 int null, depkey3 int null, depkey4 int null, depkey5 int null, depkey6 int null, depkey7 int null, depkey8 int null, unique (id, type, depid, key1, key2, key3, key4, key5, key6, key7, key8))')
	exec ('update '+@name+'..sysobjects set xtype=''S'' where name=''syskeys''')
	fetch next from cr into @name
end
close cr
deallocate cr
GO
IF (SELECT COUNT(*) FROM sysobjects WHERE name='sp_helpsql')>0 DROP PROCEDURE dbo.sp_helpsql
GO
CREATE PROC sp_helpsql
@in_command varchar(30) = NULL
AS
DECLARE @num_commands tinyint
DECLARE @original_command varchar(30)
/*******************************************************************/
/*  sp_helpsql gives help on SQL commands supported by SQL Server  */
/*      4 situations are covered:                                  */
/*          1. No additional parameters                            */
/*             Returns: Help on how to use sp_helpsql              */
/*          2. Partial parameter input by the user                 */
/*             Returns: The name of all commands that begin with   */
/*                      the string input by the user.  The user    */
/*                      can resubmit the request for help with     */
/*                      the correct command name.                  */
/*          3. A unique parameter passed from the user             */
/*             Returns: A brief definition and syntax on command.  */
/*          4. A parameter which does not match any help commands. */
/*             return:  No help available for command: parameter   */
/*******************************************************************/

/* first deal with no parameter passed, which means to simply give */
/* usage syntax and help                                           */
IF @in_command IS NULL
    BEGIN
	PRINT ' '
 	PRINT 'sp_helpsql supplies help on Transact-SQL statements, server-supplied stored '
        PRINT '    procedures, and the following special topics: '
	PRINT ' '
	PRINT '         Comments              Expression            Variables'
	PRINT '         Control of Flow       Functions             Wildcards'
	PRINT '         Cursors               Operators'
	PRINT '         Datatypes             Transactions'
	PRINT ' '
	PRINT 'Syntax:  sp_helpsql [''topic'']'
	PRINT ' '
	PRINT ' '
	PRINT 'For parameter options and syntax restrictions, see the Books On-line.'
	PRINT ' '
	/* all done, so leave now */
	RETURN
    END
ELSE
    BEGIN
	SELECT @original_command = @in_command
	SELECT @in_command = UPPER(@in_command)
	/* see if we got a unique hit on command */
	SELECT @num_commands = COUNT(DISTINCT command) FROM master..helpsql WHERE
		UPPER(command) LIKE @in_command
	IF @num_commands = 1
	    BEGIN
		SELECT 'Transact-SQL Syntax Help' = ('  ' + helptext)
			FROM master..helpsql
				WHERE UPPER(command) LIKE @in_command
			ORDER BY ordering
		RETURN
	    END
	ELSE
	/* what was input did not get a direct hit, so now look for a part */
	/* of a command as input */
	SELECT @in_command = @in_command + '%'
	SELECT @num_commands = COUNT(DISTINCT command) FROM master..helpsql WHERE
		UPPER(command) LIKE @in_command
	/* if num_command > 1 then more than 1 command has been found*/
	IF @num_commands > 1
	    BEGIN
		PRINT ' '
		PRINT 'You have entered a non-unique topic.  More information can be obtained'
		PRINT 'for the following topics:'
		PRINT ' '
		SELECT DISTINCT 'Transact-SQL command' = command FROM master..helpsql WHERE
			UPPER(command) LIKE @in_command
		RETURN
	    END
	ELSE
	/* if num_command = 1 then give help for that 1 command */
	IF @num_commands = 1
	    BEGIN
		SELECT 'Transact-SQL Syntax Help' = ('  ' + helptext)
			FROM master..helpsql
				WHERE UPPER(command) LIKE @in_command
			ORDER BY ordering
		RETURN
	    END
	ELSE
	/* if we got here we have no help on the command requested by the */
	/* user                                                           */
	    BEGIN
		DECLARE @nohelp varchar(72)
		SELECT @nohelp = 'No help available for ' + @original_command
		PRINT @nohelp
		RETURN
	    END
    END
GO
IF (SELECT COUNT(*) FROM sysobjects WHERE name='sp_dropkey')>0 DROP PROCEDURE dbo.sp_dropkey
GO
CREATE PROCEDURE sp_dropkey @keytype varchar(10), @tabname varchar(92), @deptabname varchar(92) = null AS

declare @id int				/* id of @tabname */
declare @uid smallint			/* owner of @tabname */
declare @depid int			/* id of related table */
declare @depuid smallint		/* owner of @related table */
declare @dbname varchar(30)
declare @db varchar(30), @s varchar(1000)
select @db=db_name(dbid) from master..sysprocesses where spid=@@spid

/*
**  First make sure that the key type is ok.
*/
if lower(@keytype) not in ('primary', 'foreign', 'common')
	begin
		raiserror(15145,-1,-1)
		return (1)
	end

/*
**  Check to see that the tabname is local.
*/
if @tabname like '%.%.%'
	and substring(@tabname, 1, charindex('.', @tabname) - 1) <> db_name()
	begin
		raiserror(15078,-1,-1)
		return (1)
	end

if @deptabname like '%.%.%'
	and substring(@deptabname, 1, charindex('.', @deptabname) - 1) <> db_name()
	begin
		raiserror(15078,-1,-1)
		return (1)
	end

/*
**  Get the ids of the @tabname and @deptabname.
*/
select @id = id, @depid = object_id(@deptabname), @uid = uid
		from sysobjects
			where id = object_id(@tabname)
if @id is null
	begin
		select @dbname = db_name()
		raiserror(15009,-1,-1,@tabname,@dbname)
		return (1)
	end

if @uid <> user_id()
	begin
		raiserror(15146,-1,-1)
		return (1)
	end

/*
**  If primary key, just drop it.
*/
if lower(@keytype) = 'primary'
	begin
		select @s='delete from '+@db+'..syskeys where id = '+convert(varchar, @id)+ ' and type = 1'
		exec (@s)

		if @@rowcount = 0
			begin
				raiserror(15147,-1,-1)
				return (1)
			end

		else
			print 'Primary key for the table or view dropped.'

		/*
		**  Check to see if there are any foreign keys dependent on the
		**  primary key.  If so -- drop them.
		*/
		select @s='delete from '+@db+'..syskeys where depid = '+convert(varchar, @id)+' and type = 2'
		exec (@s)

		if @@rowcount <> 0
			print 'Dependent foreign keys were also dropped.'

		return (0)
	end

/*
**  It's either a foreign or common key so we need to verify the
**  existence of the @deptabname.
*/
if @depid is null
	begin
		/*
		**  Was the @deptabname supplied?
		*/
		if @deptabname is null
			begin
				raiserror(15148,-1,-1)
				return (1)
			end

		/*
		**  It was supplied but it doesn't exist.
		*/
		raiserror(15081,-1,-1)
		return (1)
	end


/*
**  If foreign key, get rid of it.
*/
if lower(@keytype) = 'foreign'
	begin
		/*
		**  Get rid of the foreign key entry.
		*/
		select @s='delete from '+@db+'..syskeys where type = 2 and id = '+convert(varchar, @id)+' and depid = '+convert(varchar, @depid)
		exec (@s)

		if @@rowcount = 0
			begin
				raiserror(15149,-1,-1)
				return (1)
			end

		print 'Foreign key dropped.'

		return (0)
	end

/*
**  Key type must be common so just get rid of the common keys
**  with the right ids and depids.  Since whenever a common key is defined
**  it is added to both of the tables involved, we'll get rid of both of
**  those entries.
*/
delete from syskeys
	where type = 3
		and id = @id
		and depid = @depid

if @@rowcount = 0
	begin
		raiserror(15150,-1,-1)
		return (1)
	end

return (0)
GO
IF OBJECT_ID('sp_foreignkey') IS NOT NULL DROP PROC sp_foreignkey
GO
CREATE PROCEDURE sp_foreignkey @tabname nvarchar(512), @pktabname nvarchar(92), @col1 sysname, @col2 sysname = NULL, @col3 sysname = NULL, @col4 sysname = NULL, @col5 sysname = NULL, @col6 sysname = NULL, @col7 sysname = NULL, @col8 sysname = NULL
AS

declare @s nvarchar(4000)
declare @objida int	/* id of table we are doing */
declare @objidb int	/* id of table with primary key */
declare @uid smallint	/* id of owner of the table */
declare @cnt    int	/* how many columns are in foreign key */

declare @pkey1 int	/* colids of the foreign key */
declare @pkey2 int
declare @pkey3 int
declare @pkey4 int
declare @pkey5 int
declare @pkey6 int
declare @pkey7 int
declare @pkey8 int

declare @fkey1 int	/* colids of the primary key */
declare @fkey2 int
declare @fkey3 int
declare @fkey4 int
declare @fkey5 int
declare @fkey6 int
declare @fkey7 int
declare @fkey8 int

/*
**  Check to see that the tabname is local.
*/
if @tabname like '%.%.%'
	and substring(@tabname, 1, charindex('.', @tabname) - 1) <> db_name()
	begin
		raiserror('Foreign Object db must be same like current db.', 15, 1)
		return (1)
	end

if @pktabname like '%.%.%'
	and substring(@pktabname, 1, charindex('.', @pktabname) - 1) <> db_name()
	begin
		raiserror('Primary Object db must be same like current db.', 15, 1)
		return (1)
	end

select @objida = id, @uid = uid
	from sysobjects
		where id = object_id(@tabname)

if @objida is NULL
	begin
		raiserror ('Table %s Not Found.', 15, 1, @tabname)
		return (1)
	end

select @objidb = id
	from sysobjects
		where id = object_id(@pktabname)

if @objidb is NULL
	begin
		raiserror ('Table %s Not Found.', 15, 1, @pktabname)
		return (1)
	end

/*
**  Now check to see that the foreign key columns exist.
*/
select @cnt = 1, @fkey1 = colid
	from syscolumns
		where name = @col1
			and id = @objida
if @fkey1 is null
	begin
		raiserror('Column %s doesn''t exist.', 15, 1, @col1)
		return (1)
	end

if @col2 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @fkey2 = colid
			from syscolumns
			where name = @col2
			and id = @objida

		if @fkey2 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col2)
				return (1)
			end
	end
else goto foreign_ok

if @col3 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @fkey3 = colid
			from syscolumns
			where name = @col3
			and id = @objida

		if @fkey3 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col3)
				return (1)
			end
	end
else goto foreign_ok

if @col4 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @fkey4 = colid
			from syscolumns
			where name = @col4
			and id = @objida

		if @fkey4 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col4)
				return (1)
			end
	end
else goto foreign_ok

if @col5 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @fkey5 = colid
			from syscolumns
			where name = @col5
			and id = @objida

		if @fkey5 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col5)
				return (1)
			end
	end
else goto foreign_ok

if @col6 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @fkey6 = colid
			from syscolumns
			where name = @col6
			and id = @objida

		if @fkey6 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col6)
				return (1)
			end
	end
else goto foreign_ok

if @col7 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @fkey7 = colid
			from syscolumns
			where name = @col7
			and id = @objida

		if @fkey7 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col7)
				return (1)
			end
	end
else goto foreign_ok

if @col8 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @fkey8 = colid
			from syscolumns
			where name = @col8
			and id = @objida

		if @fkey8 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col8)
				return (1)
			end
	end


/*
**  If we made it this far then all the columns for the foreign key are ok.
*/
foreign_ok:

/*
**  Now let's check out the primary key that the foreign key is on.
**  There must be the same number of columns in the key and the
**  base types of the columns must agree.
*/
declare @db sysname
select @db=db_name()

create table #tmp (key1 int null, key2 int null, key3 int null, key4 int null, key5 int null, key6 int null, key7 int null, key8 int null)
select @s=N'insert #tmp select key1, key2, key3, key4, key5, key6, key7, key8 from '+@db+N'..syskeys where id = '+convert(nvarchar, @objidb)+
		N' and type = 1 and keycnt = '+convert(nvarchar, @cnt)
exec (@s)

select @pkey1 = key1, @pkey2 = key2, @pkey3 = key3, @pkey4 = key4,
	@pkey5 = key5, @pkey6 = key6, @pkey7 = key7, @pkey8 = key8
		from #tmp
drop table #tmp

/*
**  If @pkey1 is null then there is no such primary key or the number of
**  columns in the primary key are not the same as the number of columns
**  in the foreign key.
*/
if @pkey1 is null
begin
	if exists (select * from syskeys where id = @objidb and type = 1)
		raiserror('Primary key does not exist with the same number of columns as the foreign key.', 15, 1)
	else
		raiserror('Primary key does not exist.', 15, 1)

	return (1)
end

/*
**  Everything is consistent so add the foreign key to syskeys.
*/
doinsert:

select @s=N'insert '+@db+N'..syskeys (id, type, depid, keycnt, size, key1, key2, key3, key4, key5,
	key6, key7, key8, depkey1, depkey2, depkey3, depkey4, depkey5,
	depkey6, depkey7, depkey8)
values ('+convert(nvarchar, @objida)+N', 2, '+convert(nvarchar, @objidb)+N', '+convert(nvarchar, @cnt)+N', 0, '+convert(nvarchar, @fkey1)+N', '
	+convert(nvarchar, isnull(@fkey2, 0))+N', '+convert(nvarchar, isnull(@fkey3, 0))+N', '+convert(nvarchar, isnull(@fkey4, 0))+N', '+convert(nvarchar, isnull(@fkey5, 0))+N', '+
	convert(nvarchar, isnull(@fkey6, 0))+N', '+convert(nvarchar, isnull(@fkey7, 0))+N', '+convert(nvarchar, isnull(@fkey8, 0))+N', '+convert(nvarchar, @pkey1)+N', '+
	convert(nvarchar, @pkey2)+N', '+convert(nvarchar, @pkey3)+N', '+convert(nvarchar, @pkey4)+N', '+convert(nvarchar, @pkey5)+','+
	convert(nvarchar, @pkey6)+N', '+convert(nvarchar, @pkey7)+N', '+convert(nvarchar, @pkey8)+N')'
exec (@s)

print 'New foreign key added.'

return (0)
GO
IF OBJECT_ID('sp_primarykey') IS NOT NULL DROP PROC sp_primarykey
GO
CREATE PROCEDURE sp_primarykey @tabname nvarchar(512), @col1 sysname, @col2 sysname = NULL, @col3 sysname = NULL, @col4 sysname = NULL, @col5 sysname = NULL, @col6 sysname = NULL, @col7 sysname = NULL, @col8 sysname = NULL
AS

declare @objid int			/* object id of the table */
declare @uid smallint			/* owner id of the object */
declare @cnt smallint			/* howmany columns in key */
declare @key1 smallint			/* colids of the columns in the key */
declare @key2 smallint
declare @key3 smallint
declare @key4 smallint
declare @key5 smallint
declare @key6 smallint
declare @key7 smallint
declare @key8 smallint
declare @dbname sysname

select @key1=0, @key2=0, @key3=0, @key4=0, @key5=0, @key6=0, @key7=0, @key8=0
/*
**  Check to see that the tabname is local.
*/
if @tabname like '%.%.%' and
	substring(@tabname, 1, charindex('.', @tabname) - 1) <> db_name()
	begin
		raiserror('Object db must be same like current db.', 15, 1)
		return (1)
	end

/*
**  See if we can find the object.  It must be a system table, user table,
**  or view.  The low 4 bits of sysobjects.sysstat indicate what the
**  object type is -- it's more reliable than using sysobjects.type which
**  could change.
*/
declare @db sysname
select @db=db_name()
select @objid = id, @uid = uid
	from sysobjects
		where id = object_id(@tabname)
if @objid is NULL
	begin
		raiserror ('Table %s Not Found.', 15, 1, @tabname)
		return (1)
	end

/*
**  Now check out each column argument to verify its existence.
*/
select @cnt = 1, @key1 = colid
	from syscolumns
		where name = @col1
			and id = @objid
if @key1 is NULL
	begin
		raiserror('Column %s doesn''t exist.', 15, 1, @col1)
		return (1)
	end

if @col2 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @key2 = colid
			from syscolumns
			where name = @col2
			and id = @objid

		if @key2 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col2)
				return (1)
			end
	end
else goto doinsert

if @col3 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @key3 = colid
			from syscolumns
			where name = @col3
			and id = @objid

		if @key3 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col3)
				return (1)
			end
	end
else goto doinsert

if @col4 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @key4 = colid
			from syscolumns
			where name = @col4
			and id = @objid

		if @key4 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col4)
				return (1)
			end
	end
else goto doinsert

if @col5 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @key5 = colid
			from syscolumns
			where name = @col5
			and id = @objid

		if @key5 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col5)
				return (1)
			end
	end
else goto doinsert

if @col6 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @key6 = colid
			from syscolumns
			where name = @col6
			and id = @objid

		if @key6 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col6)
				return (1)
			end
	end
else goto doinsert

if @col7 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @key7 = colid
			from syscolumns
			where name = @col7
			and id = @objid

		if @key7 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col7)
				return (1)
			end
	end
else goto doinsert

if @col8 IS NOT NULL
	begin
		select @cnt = @cnt + 1, @key8 = colid
			from syscolumns
			where name = @col8
			and id = @objid

		if @key8 is NULL
			begin
				raiserror('Column %s doesn''t exist.', 15, 1, @col8)
				return (1)
			end
	end

doinsert:
declare @s nvarchar(4000)
select @s=N'insert into '+@db+N'..syskeys
	(id, type, depid, keycnt, size, key1, key2, key3, key4, key5,
		key6, key7, key8)
values ('+convert(nvarchar, @objid)+N', 1, NULL,'+convert(nvarchar, @cnt)+N', 0, '+convert(nvarchar,  @key1)+N','+convert(nvarchar, @key2)+N','
+convert(nvarchar, @key3)+N','+convert(nvarchar, @key4)+N','+convert(nvarchar, @key5)+N','+convert(nvarchar, @key6)+N','+convert(nvarchar, @key7)+N','
+convert(nvarchar, @key8)+N')'
exec (@s)

print 'New primary key added.'
return (0)
GO
exec sp_configure 'allow updates', 0
reconfigure with override
go
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER DATABASE', 1, 'ALTER DATABASE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER DATABASE', 2, 'Increases the amount of disk space allocated to a database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER DATABASE', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER DATABASE', 4, 'ALTER DATABASE <database_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER DATABASE', 5, '     [ON {DEFAULT | <database_device>} [= <size>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER DATABASE', 6, '          [, <database_device> [= <size>]]...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER DATABASE', 7, '[FOR LOAD]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER DATABASE', 8, 'test')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 1, 'ALTER TABLE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 2, 'Adds new columns or constraints to an existing table.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 4, 'ALTER TABLE <database>.[<owner>.]<table_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 5, '[WITH {CHECK | NOCHECK}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 6, '{{CHECK | NOCHECK} CONSTRAINT')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 7, '{<constraint_name> | ALL} |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 8, '[ADD')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 9, '     {<col_name> <column_properties> [<column_constraints>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 10, '     | [[,] <table_constraint>]}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 11, '          [, {<next_col_name> | <next_table_constraint>}]...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 12, '|')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 13, '[DROP CONSTRAINT]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 14, '     <constraint_name> [, <constraint_name2>]...]}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 15, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 16, '<column_properties> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 17, '     <datatype> [NULL | IDENTITY[(<seed>, <increment>)]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 18, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 19, '<column_constraints> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 20, '  For a column-level constraint:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 20, '    [CONSTRAINT <constraint_name> ]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 21, '    {PRIMARY KEY [CLUSTERED | NONCLUSTERED][ (<col_name>)]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 22, '         | UNIQUE [CLUSTERED | NONCLUSTERED] [(<col_name>)]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 23, '               [WITH FILLFACTOR = <fillfactor> ]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 24, '         | FOREIGN KEY [(<col_name>)]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 25, '               REFERENCES [(<ref_col>)][NOT FOR REPLICATION]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 26, ' 		| CHECK [NOT FOR REPLICATION] (<expression>)}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 27, '<table_constraints> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 28, '  For a table-level constraint:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 29, '     [CONSTRAINT <constraint_name> ]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 30, '          {PRIMARY KEY [CLUSTERED | NONCLUSTERED]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 31, '               (<col_name> [, <col_name2> [..., <col_name16>]])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 32, '          | UNIQUE [CLUSTERED | NONCLUSTERED]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 33, '               (<col_name> [, <col_name2> [..., <col_name16>]])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 34, '               [WITH FILLFACTOR = <fillfactor>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 35, '          | FOREIGN KEY (<col_name> [, <col_name2> [..., <col_name16>]])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 36, '               REFERENCES [<owner>.]<ref_table> (<ref_col>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 37, '                    [, <ref_col2> [..., <ref_col16>]])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 38, '               [NOT FOR REPLICATION]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ALTER TABLE', 39, '          | CHECK [NOT FOR REPLICATION] (<expression>)}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 1, 'CASE Expression')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 2, 'The CASE expression allows SQL expressions to be simplified for')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 3, 'conditional values. The CASE expression in SQL Server 6.0 is ANSI')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 4, 'SQL-92-compliant and allowed anywhere an expression is used.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 6, 'Simple CASE expression:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 7, '     CASE <expression>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 8, '          WHEN <expression1> THEN <expression1>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 9, '          [[WHEN <expression2> THEN <expression2>] [...]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 10, '          [ELSE <expressionN>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 11, '     END')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 12, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 13, 'Searched CASE expression:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 14, '     CASE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 15, '          WHEN <Boolean_expression1> THEN <expression1>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 16, '          [[WHEN <Boolean_expression2> THEN <expression2> ] [...]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 17, '          [ELSE <expressionN>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 18, '     END')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 19, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 20, 'CASE-related functions:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 21, '     COALESCE (<expression1>, <expression2>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 22, '     COALESCE (<expression1>, <expression2>, ... <expressionN>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CASE', 23, '     NULLIF (<expression1>, <expression2>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CHECKPOINT', 1, 'CHECKPOINT Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CHECKPOINT', 2, 'Forces all dirty pages (those that have been updated since the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CHECKPOINT', 3, 'last checkpoint) in the current database to be written to disk.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CHECKPOINT', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CHECKPOINT', 5, 'CHECKPOINT')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('COMMENTS', 1, 'Comments')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('COMMENTS', 2, 'Provide user-documented information about SQL statements, statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('COMMENTS', 3, 'blocks, and stored procedures.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('COMMENTS', 4, '/* <text of comment> */')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('COMMENTS', 5, 'Or')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('COMMENTS', 6, '-- <text of comment>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 1, 'Control-of-Flow Language')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 2, 'Controls the flow of execution of SQL statements, statement blocks, and')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 3, 'stored procedures. These keywords can be used in ad hoc SQL')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 4, 'statements, in batches, and in stored procedures.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 6, 'These are the control-of-flow keywords:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 7, 'BEGIN...END      Defines a statement block.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 8, 'GOTO <label>     Continues processing at the statement following the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 9, '                 label as defined by <label>.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 10, 'IF...ELSE        Defines conditional and, optionally, alternate')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 11, '                 execution when a condition is false.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 12, 'RETURN           Exits unconditionally.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 13, 'WAITFOR          Sets a delay for statement execution.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 14, 'WHILE            Repeats statements while a specific condition is true.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 15, '...BREAK         Exits the innermost WHILE loop.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CONTROL OF FLOW', 16, '...CONTINUE      Restarts a WHILE loop.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN...END', 1, 'BEGIN...END Block')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN...END', 2, 'Encloses a series of SQL statements so that control-of-flow language,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN...END', 3, 'such as IF...ELSE, affects the performance of a group of statements')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN...END', 4, 'instead of only the statement that immediately follows.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN...END', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN...END', 6, 'BEGIN...END blocks can be nested.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN...END', 7, 'BEGIN')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN...END', 8, '     {sql_statement | <statement_block>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN...END', 9, 'END')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GOTO...LABEL', 1, 'GOTO...LABEL Block')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GOTO...LABEL', 2, 'Alters the flow of execution to a label. The SQL statement(s) following')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GOTO...LABEL', 3, 'GOTO are skipped and processing continues at the label. GOTO statements')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GOTO...LABEL', 4, 'and labels can be used anywhere within a procedure, batch, or')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GOTO...LABEL', 5, 'statement block, and they can be nested.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GOTO...LABEL', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GOTO...LABEL', 7, 'Define the label:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GOTO...LABEL', 8, '     <label>:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GOTO...LABEL', 9, 'Alter the execution:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GOTO...LABEL', 10, '     GOTO <label>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN DISTRIBUTED TRANSACTION', 1, 'BEGIN DISTRIBUTED TRANSACTION Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN DISTRIBUTED TRANSACTION', 1, 'Used to start a transaction that is processed on one or')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN DISTRIBUTED TRANSACTION', 1, 'more remote servers. MS DTC manages the distributed transaction.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN DISTRIBUTED TRANSACTION', 1, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN DISTRIBUTED TRANSACTION', 1, 'BEGIN DISTRIBUTED TRANSACTION [<transaction_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('IF...ELSE', 1, 'IF...ELSE Block')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('IF...ELSE', 2, 'Imposes conditions on the execution of a SQL statement. The SQL')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('IF...ELSE', 3, 'statement following an IF keyword and its condition is executed if the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('IF...ELSE', 4, 'condition is satisfied (when the Boolean expression returns true). The')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('IF...ELSE', 5, 'optional ELSE keyword introduces an alternate SQL statement that is')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('IF...ELSE', 6, 'executed when the IF condition is not satisfied (when the Boolean')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('IF...ELSE', 7, 'expression returns false).')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('IF...ELSE', 8, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('IF...ELSE', 9, 'IF <Boolean_expression>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('IF...ELSE', 10, '     {<sql_statement> | <statement_block>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('IF...ELSE', 11, '[ELSE [<Boolean_expression>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('IF...ELSE', 12, '     {<sql_statement> | <statement_block>}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RETURN', 1, 'RETURN Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RETURN', 2, 'Exits unconditionally from a query or procedure. RETURN is immediate and')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RETURN', 3, 'complete; statements following RETURN are not executed.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RETURN', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RETURN', 5, 'RETURN ([<integer_expression>])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WAITFOR', 1, 'WAITFOR Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WAITFOR', 2, 'Specifies a time, time interval, or event that triggers execution of a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WAITFOR', 3, 'statement block, stored procedure, or transaction.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WAITFOR', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WAITFOR', 5, 'WAITFOR {DELAY ''<time>'' | TIME ''<time>''}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WHILE', 1, 'WHILE Construct')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WHILE', 2, 'Sets a condition for the repeated execution of an <sql_statement> or')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WHILE', 3, 'statement block. The statements are executed repeatedly as long as the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WHILE', 4, 'specified condition is true. The execution of statements in the WHILE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WHILE', 5, 'loop can be controlled from inside the loop with the BREAK and CONTINUE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WHILE', 6, 'keywords.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WHILE', 7, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WHILE', 8, 'WHILE <Boolean_expression>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WHILE', 9, '       {<sql_statement> | <statement_block>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WHILE', 10, '     [BREAK]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WHILE', 11, '       {<sql_statement> | <statement_block>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WHILE', 12, '     [CONTINUE]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DATABASE', 1, 'CREATE DATABASE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DATABASE', 2, 'Creates a new database. You must be in the master database to create a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DATABASE', 3, 'new database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DATABASE', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DATABASE', 5, 'CREATE DATABASE <database_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DATABASE', 6, '[ON {DEFAULT | <database_device>} [= <size>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DATABASE', 7, '     [, <database_device> [= <size>]]...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DATABASE', 8, '[LOG ON <database_device> [= <size>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DATABASE', 9, '     [, <database_device> [= <size>]]...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DATABASE', 10, '[FOR LOAD]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DEFAULT', 1, 'CREATE DEFAULT Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DEFAULT', 2, 'Creates an object that, when bound to a column or a user-defined')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DEFAULT', 3, 'datatype, specifies a value to be inserted into the column to which it''s')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DEFAULT', 4, 'bound (or into all columns in the case of a user-defined datatype) when')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DEFAULT', 5, 'no value is explicitly supplied during an insert.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DEFAULT', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DEFAULT', 7, 'CREATE DEFAULT [<owner>.]<<default_name>>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE DEFAULT', 8, 'AS <constant_expression>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 1, 'CREATE INDEX Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 2, 'Creates an index on a given table that either changes the physical')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 3, 'ordering of the table or provides the optimizer with a logical ordering')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 4, 'of the table to increase efficiency for queries.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 6, 'CREATE [UNIQUE] [CLUSTERED | NONCLUSTERED] INDEX <index_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 7, '     ON [[<database>.]<owner>.]<table_name> (<column_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 8, '          [, <column_name>]...)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 9, '[WITH')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 10, '     [PAD_INDEX,]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 11, '     [[,]FILLFACTOR = <fillfactor>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 12, '     [[,] IGNORE_DUP_KEY]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 13, '     [[,] SORTED_DATA | SORTED_DATA_REORG]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 14, '     [[,] IGNORE_DUP_ROW | ALLOW_DUP_ROW]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE INDEX', 15, '[ON <segment_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE PROCEDURE', 1, 'CREATE PROCEDURE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE PROCEDURE', 2, 'Creates a stored procedure (a precompiled collection of SQL statements')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE PROCEDURE', 3, 'that can take and/or return')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE PROCEDURE', 4, 'user-supplied parameters.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE PROCEDURE', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE PROCEDURE', 6, 'CREATE PROCedure [<owner>.] procedure_name [;<number>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE PROCEDURE', 7, '     [(<parameter1> [, <parameter2>]...[<parameter255>])]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE PROCEDURE', 8, '[{FOR REPLICATION} | {WITH RECOMPILE}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE PROCEDURE', 9, '     [{[WITH] | [,]} ENCRYPTION]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE PROCEDURE', 10, 'AS <sql_statements>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE RULE', 1, 'CREATE RULE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE RULE', 2, 'Creates an object called a rule, which, when bound to a column or a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE RULE', 3, 'user-defined datatype, specifies the acceptable values that can be inserted')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE RULE', 4, 'into that column.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE RULE', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE RULE', 6, 'CREATE RULE [<owner>.]<<rule_name>>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE RULE', 7, 'AS <condition_expression>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE SCHEMA', 1, 'CREATE SCHEMA Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE SCHEMA', 2, 'Creates a schema that can be thought of as a conceptual container object,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE SCHEMA', 3, 'which is the definition of the database without any data in it.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE SCHEMA', 4, 'CREATE SCHEMA')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE SCHEMA', 5, '     [AUTHORIZATION <owner>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE SCHEMA', 6, '          [<schema_element1> [<schema_element2> [...<schema_elementn>]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 1, 'CREATE TABLE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 2, 'Creates a new table.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 4, 'CREATE TABLE [<database>.[<owner>].]<table_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 6, '     {<col_name> <column_properties> [<constraint> [<constraint>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 7, '          [... <constraint>]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 8, '     | [[,] <constraint>]}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 9, '          [[,] {<next_col_name> |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 10, '          <next_constraint>}...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 11, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 12, '[ON <segment_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 13, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 14, '<column_properties> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 15, '     <datatype> [NULL | NOT NULL | IDENTITY[(<seed>, <increment>)]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 16, '<constraint> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 17, '  For a PRIMARY KEY constraint:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 18, '     [CONSTRAINT <constraint_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 19, '          PRIMARY KEY [CLUSTERED | NONCLUSTERED]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 20, '               (<col_name> [, <col_name2> [..., <col_name16>]])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 21, '               [ON <segment_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 22, '  For a UNIQUE constraint:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 23, '     [CONSTRAINT <constraint_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 24, '          UNIQUE [CLUSTERED | NONCLUSTERED]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 25, '               (<col_name> [, <col_name2> [..., <col_name16>]])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 26, '               [ON <segment_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 27, '  For a FOREIGN KEY constraint:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 28, '     [CONSTRAINT <constraint_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 29, '          [FOREIGN KEY (<col_name> [, <col_name2>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 30, '               [..., <col_name16> ]])]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 31, '               REFERENCES [<owner>.]<ref_table> [(<ref_col>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 32, '               [, <ref_col2> [..., <ref_col16>]])]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 33, '  For a DEFAULT constraint:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 34, '     [CONSTRAINT <constraint_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 35, '          DEFAULT {<constant_expression> | <niladic-function> | NULL}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 36, '               [FOR <col_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 37, '  For a CHECK constraint(s):')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 38, '     [CONSTRAINT <constraint_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TABLE', 39, '          CHECK [NOT FOR REPLICATION] (<expression>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 1, 'CREATE TRIGGER Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 2, 'Creates a trigger, a special kind of stored procedure that is executed')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 3, 'automatically when a user attempts the specified data-modification')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 4, 'statement on the specified table.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 6, 'CREATE TRIGGER [<owner>.]<<trigger_name>>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 7, 'ON [<owner>.]<table_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 8, 'FOR {INSERT, UPDATE, DELETE}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 9, '[WITH ENCRYPTION]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 10, 'AS <sql_statements>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 11, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 12, 'Or, using the IF UPDATE clause:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 13, 'CREATE TRIGGER [<owner>.]<<trigger_name>>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 14, 'ON [<owner>.]<table_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 15, 'FOR {INSERT, UPDATE}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 16, '[WITH ENCRYPTION]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 17, 'AS')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 18, 'IF UPDATE (<column_name>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE TRIGGER', 19, '[{AND | OR} UPDATE (<column_name>)...] <sql_statements>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE VIEW', 1, 'CREATE VIEW Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE VIEW', 2, 'Creates a virtual table that represents an alternative way of looking at')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE VIEW', 3, 'the data in one or more tables. You can use views as security mechanisms')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE VIEW', 4, 'by granting permission on a view but not on underlying tables.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE VIEW', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE VIEW', 6, 'CREATE VIEW [<owner>.]<view_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE VIEW', 7, '[(<column_name> [, <column_name>]...)]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE VIEW', 8, '[WITH ENCRYPTION]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CREATE VIEW', 9, 'AS <select_statement> [WITH CHECK OPTION]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 1, 'Cursors')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 2, 'Server cursors allow individual row operations to be performed on a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 3, 'given results set or on the entire set. In SQL Server 6.0, ANSI SQL')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 4, 'cursors are server-based.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 6, 'DECLARE Statement     Defines a cursor.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 7, 'OPEN Statement               Opens a declared cursor.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 8, 'FETCH Statement              Retrieves a specific row from the cursor.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 9, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 10, 'FETCH [[NEXT | PRIOR | FIRST | LAST | ABSOLUTE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 11, '     {n | @nvar} | RELATIVE {n | @nvar}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 12, '     FROM] cursor_name')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 13, '     [INTO @variable_name1, @variable_name2,...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 14, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 15, 'CLOSE Statement              Closes an open cursor.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CURSORS', 16, 'DEALLOCATE Statement         Removes the cursor data structures.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE CURSOR', 1, 'DECLARE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE CURSOR', 2, 'Defines a cursor. Once declared, row sets for cursors are assigned by')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE CURSOR', 3, 'using the OPEN statement. (The DECLARE statement can also be used to')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE CURSOR', 4, 'define the name and type of local variables for a batch or procedure.)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE CURSOR', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE CURSOR', 6, 'DECLARE <cursor_name> [INSENSITIVE] [SCROLL] CURSOR')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE CURSOR', 7, 'FOR <select_statement>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE CURSOR', 8, '[FOR {READ ONLY | UPDATE [OF <column_list>]}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPEN', 1, 'OPEN Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPEN', 2, 'Opens a cursor.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPEN', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPEN', 4, 'OPEN <cursor_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FETCH', 1, 'FETCH Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FETCH', 2, 'Retrieves a specific row from the cursor.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FETCH', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FETCH', 4, 'FETCH [[NEXT | PRIOR | FIRST | LAST |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FETCH', 5, '     ABSOLUTE {<n> | @<nvar>} | RELATIVE {<n> | @<nvar>}] FROM] <cursor_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FETCH', 6, '[INTO @<variable_name1>, @<variable_name2>, ...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CLOSE', 1, 'CLOSE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CLOSE', 2, 'Closes an open cursor. CLOSE leaves the data structures accessible for')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CLOSE', 3, 'reopening; however, modifications or fetches are not allowed until the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CLOSE', 4, 'cursor is reopened.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CLOSE', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('CLOSE', 6, 'CLOSE <cursor_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DEALLOCATE', 1, 'DEALLOCATE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DEALLOCATE', 2, 'Removes the cursor data structures. DEALLOCATE is different from CLOSE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DEALLOCATE', 3, 'in that a closed cursor can be re-opened. DEALLOCATE releases all data')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DEALLOCATE', 4, 'structures associated with the cursor and removes the definition of the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DEALLOCATE', 5, 'cursor.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DEALLOCATE', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DEALLOCATE', 7, 'DEALLOCATE <cursor_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 1, 'Datatypes')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 2, 'Datatypes specify the data characteristics of columns, stored-procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 3, 'parameters, and local variables.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 5, 'Binary                  binary[(<n>)]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 6, '                        varbinary[(<n>)]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 7, 'Character               char[(<n>)]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 8, '                        varchar[(<n>)]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 9, 'Date and time           datetime')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 10, '                        smalldatetime')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 11, 'Exact numeric           decimal[(<p>[, <s>])]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 12, '                        numeric[(<p>[, <s>])]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 13, 'Approximate numeric     float[(<n>)]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 14, '                        real')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 15, 'Integer                 int')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 16, '                        smallint')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 17, '                        tinyint')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 18, 'Monetary                money')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 19, '                        smallmoney')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 20, 'Special                 bit')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 21, '                        timestamp')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 22, '                        user-defined datatypes')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 23, 'Text and image          text')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 24, '                        image')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 25, 'Synonyms                binary varying for varbinary')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 26, '                        char varying for varchar')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 27, '                        character for char')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 28, '                        character for char(1)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 29, '                        character(<n>) for char(<n>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 30, '                        character varying(<n>) for varchar(<n>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 31, '                        dec for decimal')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 32, '                        double precision for float')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 33, '                        float[(<n>)] for n = 1-7 for real')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 34, '                        float[(<n>)] for n = 8-15 for float')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DATATYPES', 35, '                        integer for int')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 1, 'DBCC Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 2, 'Used to check the logical and physical consistency of a database, check')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 3, 'memory usage, decrease the size of a database, check performance')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 4, 'statistics, and so on. DBCC is the SQL Server Database Consistency')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 5, 'Checker.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 7, 'DBCC {')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 8, '     CHECKALLOC [(<database_name> [, NOINDEX])] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 9, '     CHECKCATALOG [(<database_name>)] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 10, '     CHECKTABLE (<table_name> [, NOINDEX | <index_id>]) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 11, '     CHECKDB [(<database_name> [, NOINDEX])] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 12, '     CHECKIDENT[(<table_name>)] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 13, '     DBREINDEX([<databases>.<owner>.<table_name>[, <index_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 14, '     [, fillfactor [,{SORTED_DATA | SORTED_DATA_REORG}]]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 15, '     DBREPAIR (<database_name>, DROPDB) [, NOINIT]) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 16, '     <dllname> (FREE) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 17, '     INPUTBUFFER (<spid>) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 18, '     MEMUSAGE |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 19, '     NEWALLOC [(<database_name> [, NOINDEX])] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 20, '     OPENTRAN ({<database_name>} | {<database_id>})')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 21, '          [WITH TABLERESULTS] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 22, '     OUTPUTBUFFER (<spid>) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 23, '     PERFMON |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 24, '     PINTABLE (<database_id>, <table_id>) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 25, '     PROCCACHE |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 26, '     SHOW_STATISTICS (<table_name>, <index_name>) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 27, '     SHOWCONTIG (<table_id>, [<index_id>]) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 28, '     SHRINKDB (<database_name> [, <new_size> [, ''MASTEROVERRIDE'']]) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 29, '     SQLPERF ({IOSTATS | LRUSTATS | NETSTATS | RASTATS [, CLEAR]} |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 30, '          {THREADS} | {LOGSPACE}) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 31, '     TEXTALL [({<database_name> | <database_id>}[, FULL | FAST])] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 32, '     TEXTALLOC [({<table_name> | <table_id>}[, FULL | FAST])] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 33, '     TRACEOFF (<trace#>) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 34, '     TRACEON (<trace#>) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 35, '     TRACESTATUS (<trace#> [, <trace#>...]) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 36, '     UNPINTABLE (<database_id>, <table_id>) |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 37, '     UPDATEUSAGE ({0 | <database_name>} [, <table_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 38, '          [, <index_id>]]) [WITH COUNT_ROWS] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 39, '     USEROPTIONS}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DBCC', 40, '	[WITH NO_INFOMSGS]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE', 1, 'DECLARE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE', 2, 'Used to define the name and type of local variables for a batch or')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE', 3, 'procedure, and to define cursors.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE', 5, 'DECLARE @<variable_name> <datatype>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DECLARE', 6, '     [, @<variable_name> <datatype>...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DELETE', 1, 'DELETE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DELETE', 2, 'Removes rows from a table.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DELETE', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DELETE', 4, 'DELETE [FROM] {<table_name> | <view_name>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DELETE', 5, '     [WHERE clause]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DELETE', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DELETE', 7, 'Transact-SQL extension Syntax:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DELETE', 8, 'DELETE [FROM] {<table_name> | <view_name>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DELETE', 9, '     [FROM {<table_name> | <view_name>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DELETE', 10, '          [, {<table_name> | <view_name>}]...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DELETE', 11, '               [..., {<table_name16> | <view_name16>}]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DELETE', 12, '[WHERE clause]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK INIT', 1, 'DISK INIT Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK INIT', 2, 'Creates a device on which a database or multiple databases can be')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK INIT', 3, 'placed. A device is an operating-system file that SQL Server pre-')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK INIT', 4, 'allocates for database use.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK INIT', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK INIT', 6, 'DISK INIT')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK INIT', 7, '     NAME = ''<logical_name>'',')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK INIT', 8, '     PHYSNAME = ''<physical_name>'',')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK INIT', 9, '     VDEVNO = <virtual_device_number>,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK INIT', 10, '     SIZE = <number_of_2K_blocks>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK INIT', 11, '[, VSTART = <virtual_address>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK MIRROR', 1, 'DISK MIRROR Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK MIRROR', 2, 'Creates a software image of the SQL Server device.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK MIRROR', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK MIRROR', 4, 'DISK MIRROR')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK MIRROR', 5, '     NAME = ''<logical_name>'',')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK MIRROR', 6, '     MIRROR = ''<physical_name>''')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK MIRROR', 7, '     [, WRITES = {SERIAL | NOSERIAL}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK UNMIRROR', 1, 'DISK UNMIRROR Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK UNMIRROR', 2, 'Temporarily pauses software mirroring for the SQL Server device. Often')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK UNMIRROR', 3, 'this is useful when large non-logged operations are occurring against')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK UNMIRROR', 4, 'the database and when a database backup (using the DUMP statement) will')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK UNMIRROR', 5, 'be performed after the non-logged operations finish.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK UNMIRROR', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK UNMIRROR', 7, 'DISK UNMIRROR')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK UNMIRROR', 8, '     NAME = ''<logical_name>''')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK UNMIRROR', 9, '     [, SIDE = {PRIMARY | SECONDARY}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK UNMIRROR', 10, '     [, MODE = {RETAIN | REMOVE}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REMIRROR', 1, 'DISK REMIRROR Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REMIRROR', 2, 'Resumes software mirroring for the SQL Server device.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REMIRROR', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REMIRROR', 4, 'DISK REMIRROR')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REMIRROR', 5, '     NAME = ''<logical_name>''')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REFIT', 1, 'DISK REFIT Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REFIT', 2, 'Restores usage information from the system tables when a device exists')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REFIT', 3, '(the file is present) but the entries in the sysusages table no longer')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REFIT', 4, 'exist. This occurs after a damaged master database is restored and the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REFIT', 5, 'master database is incomplete (databases and devices were added or')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REFIT', 6, 'altered since the last backup of master).')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REFIT', 7, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REFIT', 8, 'DISK REFIT')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 1, 'DISK REINIT Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 2, 'Restores the device entries to the system tables when a device exists')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 3, '(the file is present) and the entry in the sysdevices table no longer')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 4, 'exists. This occurs after a damaged master database is restored and the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 5, 'master database is incomplete (databases and devices were added or')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 6, 'altered since the last backup of master). This is the first step for')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 7, 'restoring access to user databases. The DISK REFIT statement completes')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 8, 'the recovery.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 9, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 10, 'DISK REINIT')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 11, '     NAME = ''<logical_name>'',')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 12, '     PHYSNAME = ''<physical_name>'',')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 13, '     VDEVNO = <virtual_device_number>,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 14, '     SIZE = <number_of_2K_blocks>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK REINIT', 15, '     [, VSTART = <virtual_address>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK RESIZE', 1, 'DISK RESIZE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK RESIZE', 2, 'Allows you to expand a device. You can use DISK RESIZE on any database')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK RESIZE', 3, 'device, including the MASTER device.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK RESIZE', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK RESIZE', 5, 'DISK RESIZE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK RESIZE', 6, '     NAME = <logical_device_name>,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DISK RESIZE', 7, '     SIZE = <final_size>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP DATABASE', 1, 'DROP DATABASE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP DATABASE', 2, 'Removes one or more databases from SQL Server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP DATABASE', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP DATABASE', 4, 'DROP DATABASE <database_name> [, <database_name>...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP DEFAULT', 1, 'DROP DEFAULT Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP DEFAULT', 2, 'Removes a user-defined default from a database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP DEFAULT', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP DEFAULT', 4, 'DROP DEFAULT [<owner>.]<default_name> [, [<owner>.]<default_name>...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP INDEX', 1, 'DROP INDEX Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP INDEX', 2, 'Removes an index from a database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP INDEX', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP INDEX', 4, 'DROP INDEX [owner.]<table_name>.<index_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP INDEX', 5, '              [, [owner.]<table_name>.<index_name>...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP PROCEDURE', 1, 'DROP PROCEDURE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP PROCEDURE', 2, 'Removes user-created stored procedures from the current database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP PROCEDURE', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP PROCEDURE', 4, 'DROP PROCedure [<owner>.]<procedure_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP PROCEDURE', 5, '                   [, [<owner>.]<procedure_name>...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP RULE', 1, 'DROP RULE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP RULE', 2, 'Removes a user-specified rule from a database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP RULE', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP RULE', 4, 'DROP RULE [<owner>.]<rule_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP RULE', 5, '              [, [<owner>.]<rule_name>...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP TABLE', 1, 'DROP TABLE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP TABLE', 2, 'Removes a table definition and all data, indexes, triggers, constraints, and')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP TABLE', 3, 'permission specifications for that table from the database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP TABLE', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP TABLE', 5, 'DROP TABLE [[<database>.]<owner>.]<table_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP TABLE', 6, '               [, [[<database>.]<owner>.]<table_name>...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP TRIGGER', 1, 'DROP TRIGGER Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP TRIGGER', 2, 'Removes a trigger from a database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP TRIGGER', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP TRIGGER', 4, 'DROP TRIGGER [<owner>.]<trigger_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP TRIGGER', 5, '                 [, [<owner>.]<trigger_name>...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP VIEW', 1, 'DROP VIEW Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP VIEW', 2, 'Removes a view from a database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP VIEW', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP VIEW', 4, 'DROP VIEW [<owner>.]<view_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DROP VIEW', 5, '              [, [<owner>.]<view_name>...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 1, 'DUMP Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 2, 'Makes a backup copy of a database and its transaction log (DUMP')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 3, 'DATABASE) or only the transaction log (DUMP TRANSACTION)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 4, 'in a form that can be read into SQL Server using the LOAD statement.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 6, 'Dumping a database:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 7, '     DUMP DATABASE {<dbname> | @<dbname_var>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 8, '          TO <dump_device> [, <dump_device2> [..., <dump_device32>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 9, '      [WITH <options>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 10, '     [[,] STATS [=<percentage>]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 11, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 12, 'Dumping a transaction log:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 13, '     DUMP TRANSACTION {<dbname> | @<dbname_var>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 14, '         [TO <dump_device> [, <dump_device2> [..., <dump_device32>]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 15, '     [WITH {TRUNCATE_ONLY | NO_LOG | NO_TRUNCATE}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 16, '          {<options>}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 17, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 18, 'Dumping a table:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 19, '     DUMP TABLE [[<dbname>.]<owner>.]<table_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 20, '          TO <dump_device> [, <dump_device2> [..., <dump_device32>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 21, '          [WITH <options>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 22, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 23, 'where')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 24, '<')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 25, '<dump_device> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 26, '     { <dump_device_name> | @<dump_device_namevar>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 27, '     | {DISK | TAPE | FLOPPY | PIPE} =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 28, '          {''<temp_dump_device>'' | @<temp_dump_device_var>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 29, '     [VOLUME = {<volid> | @<volid_var>}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 30, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 31, '<options> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 32, '     [[,] {UNLOAD | NOUNLOAD}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 33, '     [[,] {INIT | NOINIT}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 34, '     [[,] {SKIP | NOSKIP}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 35, '     [[,] {{EXPIREDATE = {<date> | @<date_var>}}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 36, '          | {RETAINDAYS = {<days> | @<days_var>}}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('DUMP', 37, '     [[,] STATS [ = <percentage>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 1, 'EXECUTE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 2, 'Executes a system procedure, a user-defined stored procedure, or an')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 3, 'extended stored procedure. Also supports the execution of a character')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 4, 'string within a Transact-SQL batch.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 6, 'To execute a stored procedure:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 7, '  EXEC[ute]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 8, '  {[@<return_status> =]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 9, '     {[[[<server>.]<database>.]<owner>.]<procedure_name>[;<number>] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 10, '          @<procedure_name_var>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 11, '     [[@<parameter_name> =] {<value> | @<variable> [OUTPUT] | DEFAULT}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 12, '     [, [@<parameter_name> =] {<value> | @<variable> [OUTPUT] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 13, '     DEFAULT}]...] [WITH RECOMPILE]}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 14, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 15, 'To execute a character string:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 16, '  EXEC[ute] ({@<str_var> | ''<tsql_string>''} [{@<str_var> |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXECUTE', 17, '     ''<tsql_string>''}...])}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXPRESSION', 1, 'Expressions')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXPRESSION', 2, 'Used as variables, constants, and column names in many SQL statements,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXPRESSION', 3, 'functions and expressions. An expression returns values and can be')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXPRESSION', 4, 'nested.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXPRESSION', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXPRESSION', 6, '{<constant> | <column_name> | <function> | (<subquery>)}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXPRESSION', 7, '[{operator | AND | OR | NOT}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('EXPRESSION', 8, '{<constant> | <column_name> | <function> | (<subquery>)}...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 1, 'Functions')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 2, 'Functions return special information from the system about users,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 3, 'expressions, a database or database objects, and so on.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 5, '+ (<expression> + <expression>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 6, 'ABS (<numeric_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 7, 'ACOS (<float_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 8, 'ASCII (<char_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 9, 'ASIN (<float_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 10, 'ATAN (<float_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 11, 'ATN2 (<float_expr1>1, <float_expr2>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 12, 'AVG([ALL | DISTINCT] <expression>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 13, 'CEILING (<numeric_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 14, 'CHAR (<integer_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 15, 'CHARINDEX (''<pattern>'', <expression>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 16, 'COALESCE (<expression1>, <expression2>, ... <expressionN>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 17, 'COL_LENGTH (''<table_name>'',  ''<column_name>'')')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 18, 'COL_NAME (<table_id>,  <column_id>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 19, 'CONVERT (<datatype>[(<length>)], <expression> [, <style>])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 20, 'COS (<float_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 21, 'COT (<float_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 22, 'COUNT(*)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 23, 'COUNT([ALL | DISTINCT] <expression>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 24, 'CURRENT_TIMESTAMP (Used with DEFAULT constraints ONLY)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 25, 'CURRENT_USER (Used with DEFAULT constraints ONLY)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 26, 'DATALENGTH (''<expression>'')')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 27, 'DATALENGTH (<expression>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 28, 'DATEADD(<datepart>, <number>, <date>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 29, 'DATEDIFF(<datepart>, <date1>, <date2>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 30, 'DATENAME(<datepart>, <date>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 31, 'DATEPART(<datepart>, <date>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 32, 'DB_ID ([''<database_name>''])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 33, 'DB_NAME ([<database_id>])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 34, 'DEGREES (<numeric_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 35, 'DIFFERENCE (<char_expr1>, <char_expr2>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 36, 'EXP (<float_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 37, 'FLOOR (<numeric_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 38, 'GETDATE()')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 39, 'GETANSINULL ([''<database_name>'']')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 40, 'HOST_ID ( )')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 41, 'HOST_NAME ( )')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 42, 'IDENT_INCR (''<table_name>'')')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 43, 'IDENT_SEED (''<table_name>'')')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 44, 'INDEX_COL (''<table_name>'', <index_id>, key_id)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 45, 'ISNULL (<expression>, <value>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 46, 'LOG (<float_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 47, 'LOG10 (<float_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 48, 'LOWER (<char_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 49, 'LTRIM (<char_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 50, 'MAX([ALL | DISTINCT] <expression>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 51, 'MIN([ALL | DISTINCT] <expression>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 52, 'NULLIF (<expression1>, <expression2>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 53, 'OBJECT_ID (''<object_name>'')')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 54, 'OBJECT_NAME (object_id)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 55, 'PATINDEX (''%<pattern>%'', <expression>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 56, 'PI ( )')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 57, 'POWER (<numeric_expr1>, <numeric_expr2>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 58, 'RADIANS (<numeric_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 59, 'RAND ([<seed>])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 60, 'REPLICATE (<char_expr>, <integer_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 61, 'REVERSE (<char_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 62, 'RIGHT (<char_expr>, <integer_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 63, 'ROUND (<numeric_expr>, <length>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 64, 'RTRIM (<char_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 65, 'SESSION_USER (Used with DEFAULT constraints ONLY)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 66, 'SIGN (<numeric_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 67, 'SIN (<float_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 68, 'SOUNDEX (<char_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 69, 'SPACE (<integer_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 70, 'SQRT (<float_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 71, 'STATS_DATE (<table_id>, <index_id>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 72, 'STR (<float_expr> [, <length> [, <decimal>]])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 73, 'STUFF (<char_expr1>, <start>, <length>, <char_expr2>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 74, 'SUBSTRING (<expression>, <start>, <length>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 75, 'SUM([ALL | DISTINCT] <expression>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 76, 'SUSER_ID ([''<login_name>''])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 77, 'SUSER_NAME ([<server_user_id>])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 78, 'SYSTEM_USER (Used with DEFAULT constraints ONLY)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 79, 'TAN (<float_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 80, 'TEXTPTR (<column_name>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 81, 'TEXTVALID (''<table_name>.<column_name>'', <text_ ptr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 82, 'UPPER (<char_expr>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 83, 'USER (Used with DEFAULT constraints ONLY)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 84, 'USER_ID ([''<user_name>''])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('FUNCTIONS', 85, 'USER_NAME ([<user_id>])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 1, 'GRANT Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 2, 'Assigns permissions to users, including the permission')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 3, 'to grant permisstions to other users.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 5, 'Statement permissions:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 6, '     GRANT {ALL | <statement_list>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 7, '     TO {PUBLIC | <name_list>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 8, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 9, 'Object permissions:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 10, '     GRANT {ALL [PRIVILEGES][<column_list>] | <permission_list> [<column_list>]}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 11, '     ON {<table_name> [(<column_list>)] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 12, '         <view_name> [(<column_list>)] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 13, '         <stored_procedure_name> }')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 14, '     TO {PUBLIC | <name_list>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('GRANT', 15, '     [WITH GRANT OPTION]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('INSERT', 1, 'INSERT Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('INSERT', 2, 'Adds a new row to a table or a view, which is optionally')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('INSERT', 2, 'returned from a stored procedure.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('INSERT', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('INSERT', 4, 'INSERT [INTO]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('INSERT', 5, '     {<table_name> | <view_name>} [(<column_list>)]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('INSERT', 6, '{DEFAULT VALUES | <values_list> | <select_statement> }')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('INSERT', 7, 'EXECute {<procedure_name> | @<procedure_name_var>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('INSERT', 8, '[[@<parameter_name> =] {<value>| @<variable> [OUTPUT] | DEFAULT }')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('INSERT', 9, '[,[@<parameter_name> =] {<value>| @<variable> [OUTPUT] | DEFAULT}]...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('KILL', 1, 'KILL Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('KILL', 2, 'Terminates a user''s process based on the system process ID.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('KILL', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('KILL', 4, 'KILL <spid>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 1, 'LOAD Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 2, 'Restores a backup copy of a user database and its transaction log (LOAD')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 3, 'DATABASE) or only the transaction log (LOAD TRANSACTION) from a dump')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 4, 'that was created using the DUMP statement or an individual table (LOAD TABLE).')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 5, 'The LOAD statement can also be used to retrieve header informantion from a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 6, 'database dump (LOAD HEADERONLY).')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 7, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 8, 'Loading a database:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 9, '     LOAD DATABASE {<dbname> | @<dbname_var>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 10, '          FROM <dump_device> [, <dump_device2> [..., <dump_device32>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 11, '     [WITH <options>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 12, '          [[,] STATS [ = <percentage>]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 13, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 14, 'Loading a transaction log:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 15, '     LOAD TRANSACTION {<dbname> | @<dbname_var>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 16, '          FROM <dump_device> [, <dump_device2> [..., <dump_device32>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 17, '     [WITH <options>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 18, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 19, 'Loading a table:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 20, '     LOAD TABLE [[<dbname>.]<owner>.]<table_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 21, '          FROM <dump_device> [, <dump_device2> [..., <dump_device32>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 22, '     [WITH <options>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 23, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 24, 'Loading header information:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 25, '     LOAD HEADERONLY')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 26, '          FROM <dump_device>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 27, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 28, 'where')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 29, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 30, '<dump_device> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 31, '     { <dump_device_name> | @<dump_device_namevar>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 32, '          | {DISK | TAPE | FLOPPY | PIPE} =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 33, '          {''<temp_dump_device>'' | @<temp_dump_device_var>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 34, '     [VOLUME = {<volid> | @<volid_var>}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 35, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 36, '<options> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 37, '     [[,] {UNLOAD | NOUNLOAD}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 38, '     [[,] {SKIP | NOSKIP}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 39, '     [[,] FILE = <fileno>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 40, '     [[,] STOPAT = {<date_time> | @<date_time>}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 42, '     [[,] SOURCE = <source_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 43, '     [[,] APPEND]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('LOAD', 44, '     [[,] STATS [=<percentage>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 1, 'Operators')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 2, 'Operators are symbols used to perform mathematical computations and/or')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 3, 'comparisons between columns or variables. Comparisons can be made')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 4, 'between like datatypes without any conversion, implicit conversion, or')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 5, 'if necessary, explicit conversion. When comparisons are made between')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 6, 'implicitly converted datatypes, the result will have the greater')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 7, 'precision, the larger scale, and/or the larger/longer datatype.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 8, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 9, '-      Subtraction')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 10, '%      Modulo')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 11, '&      Bitwise AND (two operands)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 12, '*      Multiplication')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 13, '*=     Outer Join')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 14, '+      Addition')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 15, '/      Division')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 16, '<      Less than')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 17, '< >    Not equal to')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 18, '<=     Less than or equal to')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 19, '=      Equal to')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 20, '=*     Outer Join')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 21, '>      Greater than')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 22, '>=     Greater than or equal to')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 23, '^      Bitwise exclusive OR (two operands)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 24, '|      Bitwise OR (two operands)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('OPERATORS', 25, '~      Bitwise NOT (one operand)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('PRINT', 1, 'PRINT Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('PRINT', 2, 'Returns a user-defined message to the client''s message handler.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('PRINT', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('PRINT', 4, 'PRINT {''<any ASCII text>'' | @<local_variable> | @@<global_variable>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RAISERROR', 1, 'RAISERROR Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RAISERROR', 2, 'Returns a user-defined error message and sets a system flag to record')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RAISERROR', 3, 'that an error has occurred. RAISERROR lets the client retrieve an entry')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RAISERROR', 4, 'from the sysmessages table or build a message dynamically with user-')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RAISERROR', 5, 'specified severity and state information. Once defined, this message is')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RAISERROR', 6, 'sent back to the client as a server error message.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RAISERROR', 7, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RAISERROR', 8, 'RAISERROR ({<msg_id> | <msg_str>}, <severity>, <state>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RAISERROR', 9, '          [, <argument1> [, <argument2>]] )')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RAISERROR', 10, '     [WITH [LOG | NOWAIT | SETERROR]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RECONFIGURE', 1, 'RECONFIGURE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RECONFIGURE', 2, 'Installs a changed configuration option used only with the sp_configure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RECONFIGURE', 3, 'system stored procedure.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RECONFIGURE', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('RECONFIGURE', 5, 'RECONFIGURE [WITH OVERRIDE]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 1, 'REVOKE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 2, 'Revokes object and statement permissions from users.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 4, 'Statement permissions:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 5, '     REVOKE {ALL | <statement_list>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 6, '     FROM {PUBLIC | <name_list>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 7, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 8, 'Object permissions:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 9, '     REVOKE [GRANT OPTION FOR]{ALL | <permission_list>} [(<column_list>)]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 10, '     ON {<table_name> [(<column_list>)] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 11, '          <view_name> [(<column_list>)] |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 12, '          <stored_procedure_name> |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 13, '          <extended_stored_procedure_name>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 14, '     FROM {PUBLIC | <name_list>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('REVOKE', 14, '     [CASCADE]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 1, 'SELECT Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 2, 'Retrieves rows from the database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 6, 'SELECT [ALL | DISTINCT] <select_list>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 7, '     INTO [<new_table_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 8, '     [FROM <table_name> [, <table_name2> [..., <table_name16>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 9, '[WHERE <clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 10, '[GROUP BY <clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 11, '[HAVING <clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 12, '[ORDER BY <clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 13, '[COMPUTE <clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 14, '[FOR BROWSE]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 15, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 16, 'where')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 17, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 18, '<table_name> | <view_name> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 19, '     [[<database>.]<owner>.]{<table_name>. | <view_name>.}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 20, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 21, '<joined_table> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 22, '     {<table_name> CROSS JOIN <table_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 23, '     | <table_name> {INNER | LEFT [OUTER] | RIGHT [OUTER] | FULL [OUTER]}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 24, '     JOIN <table_name> ON <search_conditions>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 25, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 26, '<optimizer_hints>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 27, '     One or more of the following, separated with a space:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 28, '          [INDEX = {<index_name> | <index_id>}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 29, '          [NOLOCK]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 30, '          [HOLDLOCK]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 31, '          [UPDLOCK]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 32, '          [TABLOCK]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 33, '          [PAGLOCK]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 34, '          [TABLOCKX]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 35, '          [FASTFIRSTROW]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 36, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 37, 'WHERE <clause> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 38, '     WHERE <search_conditions>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 39, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 40, 'GROUP BY <clause> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 41, '     GROUP BY [ALL] <aggregate_free_expression>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 42, '          [[, <aggregate_free_expression>]...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 43, '          [WITH {CUBE | ROLLUP}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 44, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 45, 'HAVING <clause> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 46, '     HAVING <search_conditions>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 47, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 48, 'ORDER BY <clause> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 49, '     ORDER BY {{<table_name>. | <view_name>.}<column_name> |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 50, '               <select_list_number> | <expression>} [ASC | DESC]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 51, '             [...{{<table_name16>. | <view_name16>.}<column_name> |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 52, '                      <select_list_number> | <expression>} [ASC | DESC]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 53, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 54, 'COMPUTE <clause> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 55, '     COMPUTE <row_aggregate>(<column_name>)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 56, '               [, <row_aggregate>(<column_name>)...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SELECT', 57, '     [BY <column_name> [, <column_name>]...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 1, 'SET Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 2, 'Sets SQL Server query-processing options for the duration of the user''s')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 3, 'work session, or for the duration of a running trigger or a stored')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 4, 'procedure.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 6, 'SET {')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 7, ' ANSI_DEFAULTS {ON | OFF}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 8, '| ANSI_NULLS {OFF | ON}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 9, '| ANSI_PADDING {OFF | ON}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 10, '| ANSI_WARNINGS {OFF | ON}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 11, '| ARITHABORT')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 12, '| ARITHIGNORE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 13, '| CURSOR_CLOSE_ON_COMMIT {OFF | ON}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 14, '| DISABLE_DEF_CNST_CHK {OFF | ON}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 15, '| FIPS_FLAGGER {OFF | <level>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 16, '| FMTONLY')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 17, '| FORCEPLAN')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 18, '| IDENTITY_INSERT [<database>.[<owner>.]]<tablename>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 19, '| IMPLICIT_TRANSACTIONS {OFF | ON}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 20, '| NOCOUNT')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 21, '| NOEXEC')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 22, '| NUMERIC_ROUNDABORT {OFF | ON}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 23, '| OFFSETS {<keyword_list>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 24, '| PARSEONLY')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 25, '| PROCID')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 26, '| QUOTED_IDENTIFIER')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 27, '| SHOWPLAN')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 28, '| STATISTICS IO')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 29, '| STATISTICS TIME {ON | OFF}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 30, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 31, '| DATEFIRST <number>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 32, '| DATEFORMAT <format>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 33, '| DEADLOCKPRIORITY {LOW | NORMAL}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 34, '| LANGUAGE <language>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 35, '| REMOTE_PROC_TRANSACTIONS {OFF | ON}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 36, '| ROWCOUNT {<number> | @<int_variable>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 37, '| TEXTSIZE <number>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 38, '| TRANSACTION ISOLATION LEVEL {READ COMMITTED | READ')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 39, '     UNCOMMITTED | REPEATABLE READ | SERIALIZABLE}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SET', 40, '| XACT_ABORT {OFF | ON}}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SETUSER', 1, 'SETUSER Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SETUSER', 2, 'Allows a database owner to impersonate another user. The SETUSER')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SETUSER', 3, 'statement is used by the system administrator or a database owner when')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SETUSER', 4, 'he or she wants to adopt the identity of another user in order to use')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SETUSER', 5, 'another user''s database object, to grant permissions to that object, to')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SETUSER', 6, 'create an object, and so on.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SETUSER', 7, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SETUSER', 8, 'SETUSER [''<username>'' [WITH NORESET]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SHUTDOWN', 1, 'SHUTDOWN Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SHUTDOWN', 2, 'Stops SQL Server. Only the system administrator can execute this statement.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SHUTDOWN', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SHUTDOWN', 4, 'SHUTDOWN [WITH NOWAIT]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_column_privileges', 1, 'sp_column_privileges Catalog Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_column_privileges', 2, 'Returns the following column privilege information for a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_column_privileges', 3, 'single table in the current environment. (The GRANTOR is the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_column_privileges', 4, 'dbo, the object owner, or user to whom the dbo issued WITH GRANT permission.)')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_column_privileges', 5, ' 	TABLE_QUALIFIER  	TABLE_OWNER 	TABLE_NAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_column_privileges', 6, '  	COLUMN_NAME 	GRANTOR 		GRANTEE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_column_privileges', 7, '  	PRIVILEGE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_column_privileges', 8, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_column_privileges', 9, 'sp_column_privileges <table_name> [, <table_owner>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_column_privileges', 10, '     [, <table_qualifier>] [, <column_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 1, 'sp_columns Catalog Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 2, 'Returns column information for a single object that can be queried in')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 3, 'the current environment. The returned columns belong to a table or a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 4, 'view and contain the following column headings:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 6, ' 	')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 7, '  	TABLE_QUALIFIER		TABLE_OWNER			TABLE_NAME 	')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 8, '  	COLUMN_NAME 		DATA_TYPE			TYPE_NAME 	')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 9, '  	PRECISION 			LENGTH 			SCALE		')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 10, ' 	RADIX				NULLABLE 			REMARKS')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 11, ' 	COLUMN_DEF 			SQL_DATA_TYPE 		SQL_DATETIME_SUB')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 12, ' 	CHAR_OCTET_LENGTH		ORDINAL_POSITION 		IS_NULLABLE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 13, ' 	SS_DATA_TYPE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 14, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 15, 'sp_columns <object_name> [, <object_owner>] [, <object_qualifier>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 16, '     [, <column_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_columns', 17, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_databases', 1, 'sp_databases Catalog Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_databases', 2, 'Lists databases, their size and remarks, present in the SQL Server')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_databases', 3, 'installation or accessible through a database gateway.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_databases', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_databases', 5, ' 	DATABASE		DATABASE_SIZE		REMARKS')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_databases', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_databases', 7, 'sp_databases')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_datatype_info', 1, 'sp_datatype_info Catalog Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_datatype_info', 2, 'Returns the following columns of information about the datatypes')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_datatype_info', 3, 'supported by the current environment.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_datatype_info', 4, ' 	TYPE_NAME		DATA_TYPE		PRECISION')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_datatype_info', 5, ' 	LITERAL_PREFIX		LITERAL_SUFFIX		CREATE_PARAMS')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_datatype_info', 6, ' 	NULLABLE		CASE_SENSITIVE		SEARCHABLE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_datatype_info', 7, ' 	UNSIGNED_ATTRIBUTE	MONEY			AUTO_INCREMENT')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_datatype_info', 8, ' 	LOCAL_TYPE_NAME		MINIMUM_SCALE		MAXIMUM_SCALE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_datatype_info', 9, ' 	SQL_DATA_TYPE		SQL_DATETIME_SUB	NUM_PREC_RADIX')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_datatype_info', 10, ' 	INTERVAL_PRECISION	USERTYPE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_datatype_info', 11, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_datatype_info', 12, 'sp_datatype_info [<data_type>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fkeys', 1, 'sp_fkeys Catalog Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fkeys', 2, 'Returns logical foreign key information for the current environment.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fkeys', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fkeys', 4, ' 	PKTABLE_QUALIFIER  	PKTABLE_OWNER  		PKTABLE_NAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fkeys', 5, '  	PKCOLUMN_NAME  		FKTABLE_QUALIFIER  	FKTABLE_OWNER')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fkeys', 6, ' 	FKTABLE_NAME  		FKCOLUMN_NAME  		KEY_SEQ')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fkeys', 7, '  	UPDATE_RULE  		DELETE_RULE  		FK_NAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fkeys', 8, '	PK_NAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fkeys', 9, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fkeys', 10, 'sp_fkeys [<pktable_name>] [, <pktable_owner>] [, <pktable_qualifier>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fkeys', 11, '     [, <fktable_name>] [, <fktable_owner>] [, <fktable_qualifier>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_pkeys', 1, 'sp_pkeys Catalog Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_pkeys', 2, 'Returns primary key information for a single table in the current')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_pkeys', 3, 'environment.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_pkeys', 4, '	TABLE_QUALIFIER		TABLE_OWNER 		TABLE_NAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_pkeys', 5, '	COLUMN_NAME 		KEY_SEQ  		PK_NAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_pkeys', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_pkeys', 7, 'sp_pkeys <table_name> [, <table_owner>] [, <table_qualifier>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_server_info', 1, 'sp_server_info Catalog Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_server_info', 2, 'Returns the following list of attribute names and matching values')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_server_info', 3, 'for SQL Server, the database gateway, and/or the underlying data source.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_server_info', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_server_info', 5, ' 	attribute_id 		attribute_name		attribute_value')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_server_info', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_server_info', 7, 'sp_server_info [[@attribute_id =] <attribute_id>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_special_columns', 1, 'sp_special_columns Catalog Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_special_columns', 2, 'Returns the optimal set of columns that uniquely identify a row in the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_special_columns', 3, 'table and columns that are automatically updated when any value in the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_special_columns', 4, 'row is updated by a transaction.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_special_columns', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_special_columns', 6, 'SCOPE			COLUMN_NAME 		DATA_TYPE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_special_columns', 7, 'TYPE_NAME 		PRECISION		LENGTH')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_special_columns', 8, 'SCALE 		PSEUDO_COLUMN')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_special_columns', 9, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_special_columns', 10, 'sp_special_columns <table_name> [, <table_owner>] [, <table_qualifier>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_special_columns', 11, '     [, <col_type>] [, scope] [, nullable]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 1, 'sp_sproc_columns Catalog Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 2, 'Returns the following columns of information for a single stored procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 3, 'in the current environment.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 5, 'PROCEDURE_QUALIFIER 	PROCEDURE_OWNER		PROCEDURE_NAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 6, 'COLUMN_NAME 		COLUMN_TYPE 		DATA_TYPE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 7, 'TYPE_NAME		PRECISION		LENGTH')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 8, 'SCALE 		RADIX 			NULLABLE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 9, 'REMARKS		COLUMN_DEF		SQL_DATA_TYPE	')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 10, 'SQL_DATETIME_SUB   	CHAR_OCTET_LENGTH   	ORDINAL_POSITION 	')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 11, 'IS_NULLABLE 		SS_DATA_TYPE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 12, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 13, 'sp_sproc_columns <procedure_name> [, <procedure_owner>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_sproc_columns', 14, '     [, <procedure_qualifier>] [, <column_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_statistics', 1, 'sp_statistics Catalog Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_statistics', 2, 'Returns a list of all indexes on a specified table.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_statistics', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_statistics', 4, 'TABLE QUALIFIER  		TABLE_OWNER  		TABLE_NAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_statistics', 5, 'NON_UNIQUE 			INDEX_QUALIFIER		INDEX_NAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_statistics', 6, 'TYPE 				SEQ_IN_INDEX  		COLUMN_NAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_statistics', 7, 'COLLATION 			CARDINALITY  		PAGES')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_statistics', 8, 'FILTER_CONDITION')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_statistics', 9, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_statistics', 10, 'sp_statistics <table_name> [, <table_owner>] [, <table_qualifier>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_statistics', 11, '     [, <index_name>] [, <is_unique>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_stored_procedures', 1, 'sp_stored_procedures Catalog Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_stored_procedures', 2, 'Returns a list of the following columns for the stored procedures in the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_stored_procedures', 3, 'current environment .')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_stored_procedures', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_stored_procedures', 5, 'PROCEDURE_QUALIFIER 	PROCEDURE_OWNER		PROCEDURE_NAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_stored_procedures', 6, 'NUM_INPUT_PARAMS  	NUM_OUTPUT_PARAMS  	NUM_RESULT_SETS')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_stored_procedures', 7, 'REMARKS		PROCEDURE_TYPE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_stored_procedures', 8, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_stored_procedures', 9, 'sp_stored_procedures [<procedure_name>] [, <procedure_owner>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_stored_procedures', 10, '     [, <procedure_qualifier>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_table_privileges', 1, 'sp_table_privileges Catalog Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_table_privileges', 2, 'Returns the following privilege information for a single table in the current')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_table_privileges', 3, 'environment, where the GRANTOR can be a user granted the permission to')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_table_privileges', 4, 'grant by the dbo.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_table_privileges', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_table_privileges', 6, ' 		TABLE_QUALIFIER		TABLE_OWNER 		TABLE_NAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_table_privileges', 7, ' 		GRANTOR			GRANTEE			PRIVILEGE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_table_privileges', 8, ' 		IS_GRANTABLE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_table_privileges', 9, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_table_privileges', 10, 'sp_table_privileges <table_name> [, <table_owner>] [, <table_qualifier>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_tables', 1, 'sp_tables Catalog Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_tables', 2, 'Returns a list of columns for objects that can be queried in the current environ')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_tables', 3, '(that is, any object that can appear in a FROM clause).')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_tables', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_tables', 5, '	TABLE_QUALIFIER		TABLE_OWNER  		TABLE_NAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_tables', 6, '	TABLE_TYPE  		REMARKS')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_tables', 7, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_tables', 8, 'sp_tables [<table_name>] [, <table_owner>] [, <table_qualifier>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_tables', 9, '     [, <table_type>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_cmdshell', 1, 'xp_cmdshell Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_cmdshell', 2, 'Executes a given command string as an operating-system command shell and')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_cmdshell', 3, 'returns any output as rows of text.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_cmdshell', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_cmdshell', 5, 'xp_cmdshell <command_string> [, no_output]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_deletemail', 1, 'xp_deletemail Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_deletemail', 2, 'Deletes a message from the SQL Server inbox. This procedure is used by')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_deletemail', 3, 'the sp_processmail system stored procedure to process mail in the SQL')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_deletemail', 4, 'Server inbox.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_deletemail', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_deletemail', 6, 'xp_deletemail [@msg_id = ] <msg_id>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_enumgroups', 1, 'xp_enumgroups Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_enumgroups', 2, 'Provides a list of local Windows NT - based groups or a list of groups')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_enumgroups', 3, 'defined in a specified Windows NT domain.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_enumgroups', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_enumgroups', 5, 'xp_enumgroups [<domain_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_findnextmsg', 1, 'xp_findnextmsg Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_findnextmsg', 2, 'Accepts a message ID for input and returns the message ID for output.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_findnextmsg', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_findnextmsg', 4, 'xp_findnextmsg [@msg_id = <msg_id> [OUTPUT]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_findnextmsg', 5, '     [, @type = <type>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_findnextmsg', 6, '     [, @unread_only = {''TRUE'' | ''FALSE''}])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_grantlogin', 1, 'xp_grantlogin Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_grantlogin', 2, 'Grants SQL Server access to a Windows NT - based group or user.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_grantlogin', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_grantlogin', 4, 'xp_grantlogin ''<account_name>'' [, {''admin'' | ''repl'' | ''user''}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_logevent', 1, 'xp_logevent Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_logevent', 2, 'Logs a user-defined message in the SQL Server log file and/or in the Windows')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_logevent', 3, 'NT Event Viewer. When sending messages from Transact-SQL procedures, triggers,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_logevent', 4, 'batches, and so on, use the RAISERROR statement instead of xp_logevent.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_logevent', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_logevent', 6, 'xp_logevent <error_number>, <message>, [<severity>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_loginconfig', 1, 'xp_loginconfig Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_loginconfig', 2, 'Reports the login security configuration of the server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_loginconfig', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_loginconfig', 4, 'xp_loginconfig [''<config_name>'']')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_logininfo', 1, 'xp_logininfo Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_logininfo', 2, 'Reports the account, the type of account, the privilege level of the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_logininfo', 3, 'account, the map name of the account, and the permission path by which')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_logininfo', 4, 'the account has access to SQL Server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_logininfo', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_logininfo', 6, 'xp_logininfo [''<account_name>'' [, ''all'' | ''members'']')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_logininfo', 7, '     [, [@privilege] = <variable_name> OUTPUT]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_msver', 1, 'xp_msver Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_msver', 2, 'Returns and allows to be queried all SQL Server version information.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_msver', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_msver', 4, 'xp_msver [<optname>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 1, 'xp_readmail Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 2, 'Reads a mail message from the SQL Server mail inbox. This procedure is')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 3, 'used by the sp_processmail system stored procedure to process all mail')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 4, 'in the SQL Server inbox.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 6, 'xp_readmail ([@msg_id = <msg_id>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 7, '     [, @type = <type> [OUTPUT]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 8, '     [, @peek = {''TRUE'' | ''FALSE''}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 9, '     [, @suppress_attach = {''TRUE'' | ''FALSE''}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 10, '     [, @originator = @<sender> OUTPUT]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 11, '     [, @subject = @<subject> OUTPUT]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 12, '     [, @message = @<body_of_message> OUTPUT]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 13, '     [, @recipients = @<recipient_list> OUTPUT]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 14, '     [, @cc_list = @<cc_list> OUTPUT]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 15, '     [, @bcc_list = @<bcc_list> OUTPUT]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 16, '     [, @date_received = @<date> OUTPUT]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 17, '     [, @unread = {''TRUE'' | ''FALSE''}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 18, '     [, @attachments = @<temp_file_paths> OUTPUT])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 19, '     [, @skipbytes = @<bytes_to> <skip> OUTPUT])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_readmail', 20, '     [, @msg_length = @<length_in_bytes> OUTPUT])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_revokelogin', 1, 'xp_revokelogin Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_revokelogin', 2, 'Revokes SQL Server access from a Windows NT - based group or user.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_revokelogin', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_revokelogin', 4, 'xp_revokelogin ''<account_name>''')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_snmp_getstate', 1, 'xp_snmp_getstate Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_snmp_getstate', 2, 'Returns the following columns the SQL Server Simple Network Management')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_snmp_getstate', 3, 'Protocol (SNMP) agent. The state of the SNMP agent indicates whether the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_snmp_getstate', 4, 'agent is available to have the Microsoft SQL Server quried by an SNMP')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_snmp_getstate', 5, 'client.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_snmp_getstate', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_snmp_getstate', 7, 'xp_snmp_getstate [<return_status> OUTPUT]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_snmp_raisetrap', 1, 'xp_snmp_raisetrap Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_snmp_raisetrap', 2, 'Permits a client to define and send an SNMP alert to an SNMP client.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_snmp_raisetrap', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_snmp_raisetrap', 4, 'xp_snmp_raisetrap <server_name>, <database_name>, <error_message>,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_snmp_raisetrap', 5, '	<message_id>, <severity>, <user_name>, <comment>, <datetime>,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_snmp_raisetrap', 6, '	<return_status>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 1, 'xp_sqlinventory Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 2, 'Returns the following columns describing SQL Server Domain information.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 4, ' 	SERVERNAME		SQLREGISTEREDOWNER	DOMAINNAME')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 5, '  	MAJORVERSION 		MINORVERSION 		BUILDNUMBER')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 6, '	SERVERLOGINS  		MAXCONNECTIONS 		DBCOUNT')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 7, '	TOTALDEVICESIZE		SORTORDER  		CODEPAGE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 8, '	PROCEDURECACHE 		SMPSTATUS 		CONFIGUREDMEMORY')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 9, '	PRIORITYBOOST  		WORKINGSET  		PUBLISHER')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 10, '	SUBSCRIBER  		DISTRIBUTION  		SUPPORTSSNMP')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 11, '	SECURITYMODE 		NAMEDPIPE 		SPX')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 12, '	WINSOCKET		APPLETALK  		VINES')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 13, '	DECNET  		CPUBRAND 		CPUMODEL')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 14, '	CPUSTEPLEVEL		CPUCOUNT 		SERVERTOTALMEMORY')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 15, '	OPERATINGSYSTEM		OPERATINGSYSTEMBUILD 	TOTALPHYSICALDISK')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 16, '	AVAILABLEPHYSICALDISK')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 17, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqlinventory', 18, 'xp_sqlinventory {''<database_name>'', ''<table_name>'', <interval> | stop}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqltrace', 1, 'xp_sqltrace Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqltrace', 2, 'Allows database administrators and application developers to')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqltrace', 3, 'monitor and record database activity. Multiple instances of')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqltrace', 4, 'xp_sqltrace can be run simultaneously.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqltrace', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqltrace', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqltrace', 7, 'xp_sqltrace [[@Function = ]<function>][,[@EventFilter =]<eventfilter>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqltrace', 8, '[,[@LangFilter = ]''<langfilter>''][,[@RPCFilter = ]''<rpcfilter>'']')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqltrace', 9, '[,[@UserFilter = ]<userfilter>][,[@Appfilter = ]<appfilter>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqltrace', 10, '[,[@HostFilter =]<hostfilter>][,[@BufSize = ]<bufsize>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqltrace', 11, '[,[@Timeout = ]<timeout>][,[@Traceid = ]<traceid>][,[@Fulltext = ]<fulltext>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sqltrace', 12, '[,[@FullFilePath = ]''<outputfilename>''] [,[@InterEvents =]<integerevents>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_xpoption', 1, 'sp_xpoption Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_xpoption', 2, 'Sets the value of extended stored procedure options.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_xpoption', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_xpoption', 4, 'sp_xpoption {<xpname>, <option_name>, [<option_value>]}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 1, 'xp_sendmail Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 2, 'Sends a message, and/or a query results set, and/or an attachment to the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 3, 'specified recipients.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 5, 'xp_sendmail @recipient = <recipient> [; <recipient2>;')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 6, '               [...; <recipientn>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 7, '     [, @message = <message>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 8, '     [, @query = <query>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 9, '     [, @attachments = <attachments>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 10, '     [, @copy_recipients = <recipient> [; <recipient2>;')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 11, '          [...; <recipientn>]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 12, '     [, @blind_copy_recipients = <recipient> [; <recipient2>;')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 13, '          [...; <recipientn>]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 14, '     [, @subject = <subject>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 15, '     [, @type = <type>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 16, '     [, @attach_results = {''TRUE'' | ''FALSE''}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 17, '     [, @no_output = {''TRUE'' | ''FALSE''}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 18, '     [, @no_header = {''TRUE'' | ''FALSE''}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 19, '     [, @width = <width>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 20, '     [, @separator = <separator>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 21, '     [, @echo_error = {''TRUE'' | ''FALSE''}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 22, '     [, @set_user = <user>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sendmail', 23, '     [, @dbuse = <dbname>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sprintf', 1, 'xp_sprintf Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sprintf', 2, 'Formats and stores a series of characters and values in the string')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sprintf', 3, 'output parameter. Each format argument is replaced with the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sprintf', 4, 'corresponding argument.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sprintf', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sprintf', 6, 'xp_sprintf @<string> OUTPUT, <format> [, <argument>]...')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sscanf', 1, 'xp_sscanf Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sscanf', 2, 'Reads data from the string into the argument locations given by each')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sscanf', 3, 'format argument.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sscanf', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_sscanf', 5, 'xp_sscanf <string, <format>, [, <argument>]...')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_startmail', 1, 'xp_startmail Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_startmail', 2, 'Starts a SQL Server mail client session.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_startmail', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_startmail', 4, 'xp_startmail [''<user>''] [, ''<password>'']')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_stopmail', 1, 'xp_stopmail Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_stopmail', 2, 'Stops a SQL Server mail client session.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_stopmail', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_stopmail', 4, 'xp_stopmail')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_unc_to_drive', 1, 'xp_unc_to_drive Extended Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_unc_to_drive', 2, 'Converts a UNC path to a local drive.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('xp_unc_to_drive', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addarticle', 1, 'sp_addarticle Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addarticle', 2, 'Creates an article and adds it to a publication.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addarticle', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addarticle', 4, 'sp_addarticle <publication>, <article>, <source_table>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addarticle', 5, '     [, <destination_table>] [, <vertical_partition>] [, <type>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addarticle', 6, '     [, <filter>] [, <sync_object>] [, <ins_cmd>] [, <del_cmd>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addarticle', 7, '     [, <upd_cmd>] [, <creation_script>] [, <description>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addarticle', 8, '     [, <pre_creation_cmd>] [, <filter_clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addpublication', 1, 'sp_addpublication Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addpublication', 2, 'Creates a publication.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addpublication', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addpublication', 4, 'sp_addpublication <publication>, <taskid>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addpublication', 5, '     [, @restricted = {''TRUE'' | ''FALSE''}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addpublication', 6, '     [, @sync_method = {''NATIVE'' | ''CHARACTER''}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addpublication', 7, '     [, @repl_freq = {''CONTINUOUS'' | ''SNAPSHOT''}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addpublication', 8, '     [, @description = ''string description''')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addpublication', 9, '     [, @status = ''INACTIVE'' | ''ACTIVE'']]]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addpublisher', 1, 'sp_addpublisher Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addpublisher', 2, 'Adds a new publication server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addpublisher', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addpublisher', 4, 'sp_addpublisher <publisher> [, ''dist'']')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 1, 'sp_addsubscriber Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 2, 'Adds a new subscriber server and sets up a trusted remote login')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 3, 'mapping from SA of the subscriber to the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 4, 'repl_subscriber login ID on the publisher (unless system administrator')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 5, 'on the subscriber is already mapped to system administrator on the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 6, 'publisher).')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 7, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 8, 'sp_addsubscriber <subscriber> [, <type>] [, <login>] [, <password>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 9, '      [, <commit_batch_size>] [, <status_batch_size>] [, <flush_frequency>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 10, '      [, <frequency_type>] [, <frequency_interval>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 11, '      [, <frequency_relative_interval>] [, <frequency_recurrence_factor>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 12, '      [, <frequency_subday>] [, <frequency_subday_interval>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 13, '      [, <active_start_time_of_day>] [, <active_end_time_of_day>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscriber', 14, '      [, <active_start_date>] [, <active_end_date>][,<description>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscription', 1, 'sp_addsubscription Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscription', 2, 'Adds a subscription to an article and sets the subscriber''s status.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscription', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscription', 4, 'sp_addsubscription <publication> [, ''<article>''] , <subscriber>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscription', 5, '     [, <destination_db>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscription', 6, '     [, @sync_type = {''AUTOMATIC'' | ''MANUAL'' | ''NONE'' }]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsubscription', 7, '     [, @status = {''INACTIVE'' | ''ACTIVE'' | ''SUBSCRIBED'' }]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articlecolumn', 1, 'sp_articlecolumn Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articlecolumn', 2, 'Modifies columns for an article. Use sp_articlecolumn to create vertical')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articlecolumn', 3, 'partitions.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articlecolumn', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articlecolumn', 5, 'sp_articlecolumn <publication>, <article> [, ''<column>''')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articlecolumn', 6, '     [, @operation = { ''ADD'' | ''DROP'' }]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articlefilter', 1, 'sp_articlefilter Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articlefilter', 2, 'Creates a filter stored procedure used to horizontally partition data')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articlefilter', 3, 'replicated from a published table.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articlefilter', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articlefilter', 5, 'sp_articlefilter <publication>, <article> [, <filter_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articlefilter', 6, '     [, <filter_clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articletextcol', 1, 'sp_articletextcol Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articletextcol', 2, 'Sets the replication column status of a Text\Image column')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articletextcol', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articletextcol', 4, 'sp_articletextcol <artid>, <colid>,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articletextcol', 5, '    <type> = {''PUBLISH'' | ''NONSQLSUB''},  <operation> = { ''ADD'' | ''DROP''}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articleview', 1, 'sp_articleview Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articleview', 2, 'Creates the synchronization object for an article')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articleview', 3, 'when a table is filtered vertically and/or horizontally.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articleview', 4, 'This synchronization object is a view that is used as the filtered')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articleview', 5, 'source of the schema and data for the destination tables.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articleview', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articleview', 7, 'sp_articleview <publication>, <article> [, <view_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_articleview', 8, '     [, <filter_clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changearticle', 1, 'sp_changearticle Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changearticle', 2, 'Changes an article''s properties.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changearticle', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changearticle', 4, 'sp_changearticle <publication>, <article> [, <property>, <value>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changepublication', 1, 'sp_changepublication Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changepublication', 2, 'Changes publication properties.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changepublication', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changepublication', 4, 'sp_changepublication <publication> [, <property>, ''<value>'']')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscriber', 1, 'sp_changesubscriber Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscriber', 2, 'Changes the options for a subscription server. Any distribution task')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscriber', 3, 'for the publisher''s subscribers will be updated.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscriber', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscriber', 5, 'sp_changesubscriber <subscriber> [, <type> ] [, <login> ] [, <password>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscriber', 6, '     [, <commit_batch_size> ] [, <status_batch_size> ] [, <flush_frequency>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscriber', 7, '     [, <frequency_type> ] [, <frequency_interval>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscriber', 8, '     [, <frequency_relative_interval> ] [, <frequency_recurrence_factor>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscriber', 9, '     [, <frequency_subday> ] [, <frequency_subday_interval>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscriber', 10, '     [, <active_start_time_of_day> ] [, <active_end_time_of_day>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscriber', 11, '     [, <active_start_date> ] [, <active_end_date>] [, <description>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscription', 1, 'sp_changesubscription Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscription', 2, 'Is executed on a subscription server to change subscription properties')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscription', 3, 'for an article or a publication.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscription', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscription', 5, 'sp_changesubscription <publication>, <article>, <subscriber>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubscription', 6, '     [, ''<property>'', ''<value>'']')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubstatus', 1, 'sp_changesubstatus Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubstatus', 2, 'Changes the status of an existing subscriber.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubstatus', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubstatus', 4, 'sp_changesubstatus [<publication> [, <article> [, <subscriber>[,]]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changesubstatus', 5, '     <status> [, previous_status]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_create_distribution_tables', 1, 'sp_create_distribution_tables Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_create_distribution_tables', 2, 'Creates the tables in the distribution database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_create_distribution_tables', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_create_distribution_tables', 4, 'sp_create_distribution_tables')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_distcounters', 1, 'sp_distcounters Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_distcounters', 2, 'Displays the latest information for all subscription servers. Used by')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_distcounters', 3, 'SQL Performance Monitor.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_distcounters', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_distcounters', 5, 'sp_distcounters')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droparticle', 1, 'sp_droparticle Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droparticle', 2, 'Drops an article.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droparticle', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droparticle', 4, 'sp_droparticle <publication>, <article>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droppublication', 1, 'sp_droppublication Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droppublication', 2, 'Drops a publication and its associated articles.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droppublication', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droppublication', 4, 'sp_droppublication <publication>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droppublisher', 1, 'sp_droppublisher Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droppublisher', 2, 'Drops a publication server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droppublisher', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droppublisher', 4, 'sp_droppublisher <publisher> [, dist]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropsubscriber', 1, 'sp_dropsubscriber Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropsubscriber', 2, 'Drops a subscription server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropsubscriber', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropsubscriber', 4, 'sp_dropsubscriber <subscriber>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropsubscription', 1, 'sp_dropsubscription Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropsubscription', 2, 'On the publication server, drops subscriptions to a particular article,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropsubscription', 3, 'publication, or set of subscriptions.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropsubscription', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropsubscription', 5, 'sp_dropsubscription ''<publication>'', ''<article>'', ''<subscriber>''')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dsninfo', 1, 'sp_dsninfo Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dsninfo', 2, 'Returns the information value for a ODBC Data Source Name.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dsninfo', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dsninfo', 4, 'sp_dsninfo dsn [, {infotype | NULL} [, {login | NULL} [, {password | NULL}]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_enumfullsubscribers', 1, 'sp_enumfullsubscribers Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_enumfullsubscribers', 2, 'Returns a list of subscribers who have subscribed to all articles in a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_enumfullsubscribers', 3, 'specified publication.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_enumfullsubscribers', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_enumfullsubscribers', 5, 'sp_enumfullsubscribers <publication>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_enumdsn', 1, 'sp_enumdsn Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_enumdsn', 2, 'Provides a list of ODBC Data Source Names accessible to the publisher.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_enumdsn', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_enumdsn', 4, 'sp_enumdsn')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helparticle', 1, 'sp_helparticle Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helparticle', 2, 'Displays information about an article.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helparticle', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helparticle', 4, 'sp_helparticle <publication>[, <article>] [, <returnfilter>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helparticlecolumns', 1, 'sp_helparticlecolumns Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helparticlecolumns', 2, 'Displays all columns in the underlying table.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helparticlecolumns', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helparticlecolumns', 4, 'sp_helparticlecolumns <publication>, <article>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpdistributor', 1, 'sp_helpdistributor Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpdistributor', 2, 'Lists information about the distribution server, distribution database,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpdistributor', 3, 'working directory, and SQL Executive user account.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpdistributor', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpdistributor', 5, 'sp_helpdistributor')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helppublication', 1, 'sp_helppublication Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helppublication', 2, 'Displays information about a publication.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helppublication', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helppublication', 4, 'sp_helppublication [<publication>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helppublicationsync', 1, 'sp_helppublicationsync Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helppublicationsync', 2, 'Provides information about a scheduled synchronization task for a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helppublicationsync', 3, 'publication.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helppublicationsync', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helppublicationsync', 5, 'sp_helppublicationsync <publication>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpreplicationdb', 1, 'sp_helpreplicationdb Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpreplicationdb', 2, 'Returns information about a specified database or a list of all')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpreplicationdb', 3, 'publication databases on the server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpreplicationdb', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpreplicationdb', 5, 'sp_helpreplicationdb [<databasename> [, {pub | sub}]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscriberinfo', 1, 'sp_helpsubscriberinfo Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscriberinfo', 2, 'Displays the following information about a subscription server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscriberinfo', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscriberinfo', 4, ' 	publisher		subscriber		type')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscriberinfo', 5, ' 	login			password		commit_batch_size')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscriberinfo', 6, ' 	flush_frequency	frequency_type	frequency_interval')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscriberinfo', 7, ' 	frequency_recurrence_factor		frequency_subday')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscriberinfo', 8, ' 	frequency_subday_interval		active_start_time_of_day')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscriberinfo', 9, ' 	active_end_time_of_day			active_start_date')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscriberinfo', 10, ' 	active_end_date	retryattempts	retrydelay')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscriberinfo', 11, ' 	description')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscriberinfo', 12, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscriberinfo', 13, 'sp_helpsubscriberinfo <subscriber>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscription', 1, 'sp_helpsubscription Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscription', 2, 'Lists subscription information associated with a particular publication,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscription', 3, 'article, subscriber, or set of subscriptions.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscription', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsubscription', 5, 'sp_helpsubscription [<publication> [, <article> [, <subscriber> ]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_MSkill_job', 1, 'sp_MSkill_job Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_MSkill_job', 2, 'On the distribution server, removes a single job from the distribution')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_MSkill_job', 3, 'database while continuing to send all other data to the subscriber.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_MSkill_job', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_MSkill_job', 5, 'sp_MSkill_job <job_id>, <publisher>, <publisher_db> [, <subscriber>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_MSkill_job', 6, '     [, <subscriber_db>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcleanup', 1, 'sp_replcleanup Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcleanup', 2, 'Removes transactions from the distribution database tables after they')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcleanup', 3, 'have been successfully distributed to the subscriber''s database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcleanup', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcleanup', 5, 'sp_replcleanup <publisher>, <subscriber>, <retention>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcmds', 1, 'sp_replcmds Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcmds', 2, 'Treats the first client that runs sp_replcmds within a given database as the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcmds', 3, 'logreader. If another client tries to run sp_replcmds it will')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcmds', 4, 'receive error 18752, unless the first client has disconnected.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcmds', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcmds', 6, 'sp_replcmds [<maxtrans>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcounters', 1, 'sp_replcounters Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcounters', 2, 'Returns replication statistics about latency, throughput, and')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcounters', 3, 'transaction count for each published database. Used by SQL Performance')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcounters', 4, 'Monitor.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcounters', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replcounters', 6, 'sp_replcounters')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_repldone', 1, 'sp_repldone Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_repldone', 2, 'Updates the record that identifies the server''s last distributed')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_repldone', 3, 'transaction.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_repldone', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_repldone', 5, 'sp_repldone <page>, <row> [, <timestamp>] [, <numtrans>] [, <time>] [, <reset>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replflush', 1, 'sp_replflush Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replflush', 2, 'Flushes the article cache.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replflush', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replflush', 4, 'sp_replflush')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replica', 1, 'sp_replica Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replica', 2, 'Remotely sets on a subscription server a sysobjects category bit that')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replica', 3, 'marks the table as a replica.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replica', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replica', 5, 'sp_replica <tabname>, <replicated>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replstatus', 1, 'sp_replstatus Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replstatus', 2, 'Used to update the internal table structure for replication (that')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replstatus', 3, 'indicates whether the table is being replicated).')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replstatus', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replstatus', 5, 'sp_replstatus <objectID>, <status>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replsync', 1, 'sp_replsync Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replsync', 2, 'Used from a subscription server to acknowledge completion of a manual')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replsync', 3, 'synchronization.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replsync', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_replsync', 5, 'sp_replsync <publisher>, <publisher_db>, <publication> [, <article>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_repltrans', 1, 'sp_repltrans Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_repltrans', 2, 'Returns a result set of all the transactions in the publication database')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_repltrans', 3, 'transaction log that are marked for replication but that have not been')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_repltrans', 4, 'marked as distributed.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_repltrans', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_repltrans', 6, 'sp_repltrans')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_textcolstatus', 1, 'sp_textcolstatus Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_textcolstatus', 2, 'Checks the replication column status of a Text\Image column')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_textcolstatus', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_textcolstatus', 4, 'sp_textcolstatus <artid>, <tabid>, <colid>,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_textcolstatus', 5, '    <type> = {''PUBLISH'' | ''NONSQLSUB''},  <status> OUTPUT')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_subscribe', 1, 'sp_subscribe Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_subscribe', 2, 'Remotely adds a subscription to a particular article within a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_subscribe', 3, 'publication.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_subscribe', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_subscribe', 5, 'sp_subscribe <publication>, [<article> [, <desitination_db>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_subscribe', 6, '     [, @sync_type = {''AUTOMATIC'' | ''MANUAL'' | ''NONE''}]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_uninstall_publishing', 1, 'sp_uninstall_publishing Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_uninstall_publishing', 2, 'Drops all subscriptions, articles, publications, subscribers')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_uninstall_publishing', 3, ' and distribution publishers on the server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_uninstall_publishing', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_uninstall_publishing', 5, 'sp_uninstall_publishing')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unsubscribe', 6, 'sp_unsubscribe ''<publication>'', ''<article>''')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unsubscribe', 1, 'sp_unsubscribe Replication Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unsubscribe', 2, 'Remotely cancels a subscription to a particular article within a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unsubscribe', 3, 'publication, to a whole publication, or to all publications. It also')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unsubscribe', 4, 'removes all pending jobs from the distribution database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unsubscribe', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unsubscribe', 6, 'sp_unsubscribe ''<publication>'', ''<article>''')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addalert', 1, 'sp_addalert SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addalert', 2, 'Creates an alert.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addalert', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addalert', 4, 'sp_addalert <name>, <message_id>, <severity> [, <enabled>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addalert', 5, '     [, <delay_between_responses>] [, <notification_message>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addalert', 6, '     [, <include_event_description_in>] [, <database_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addalert', 7, '     [, <event_description_keyword>] [, <task_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addnotification', 1, 'sp_addnotification SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addnotification', 2, 'Sets up a notification for an alert.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addnotification', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addnotification', 4, 'sp_addnotification <alert_name>, <operator_name>, <notification_method>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addoperator', 1, 'sp_addoperator SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addoperator', 2, 'Sets up an operator (notification recipient) for use with alerts.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addoperator', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addoperator', 4, 'sp_addoperator <name> [, <enabled>] [, <email_address>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addoperator', 5, '     [, <pager_number>] [, <weekday_pager_start_time>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addoperator', 6, '     [, <weekday_pager_end_time>] [, <saturday_pager_start_time>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addoperator', 7, '     [, <saturday_pager_end_time>] [, <sunday_pager_start_time>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addoperator', 8, '     [, <sunday_pager_end_time>] [, <pager_days>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtask', 1, 'sp_addtask SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtask', 2, 'Creates a scheduled task.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtask', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtask', 4, 'sp_addtask <name> [, <subsystem>] [, <server>] [, <username>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtask', 5, '     [, <databasename>] [, <enabled>] [, <freqtype>] [, <freqinterval>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtask', 6, '     [, <freqsubtype>] [, <freqsubinterval>] [, <freqrelativeinterval>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtask', 7, '     [, <freqrecurrencefactor>] [, <activestartdate>] [, <activeenddate>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtask', 8, '     [, <activestarttimeofday>] [, <activeendtimeofday>] [, <nextrundate>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtask', 9, '     [, <nextruntime>] [, <runpriority>] [, <emailoperatorname>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtask', 10, '     [, <retryattempts>] [, <retrydelay>] [, <command>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtask', 11, '     [, <loghistcompletionlevel>] [, <emailcompletionlevel>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtask', 12, '     [, <description>] [, <tagadditionalinfo>] [, <tagobjectid>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtask', 13, '     [, <tagobjecttype>] [, @newid OUTPUT] [,@cmdexecsuccesscode]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropalert', 1, 'sp_dropalert SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropalert', 2, 'Drops an alert.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropalert', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropalert', 4, 'sp_dropalert <name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropnotification', 1, 'sp_dropnotification SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropnotification', 2, 'Drops a notification for an alert.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropnotification', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropnotification', 4, 'sp_dropnotification <alert_name>, <operator_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropoperator', 1, 'sp_dropoperator SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropoperator', 2, 'Drops an operator.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropoperator', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropoperator', 4, 'sp_dropoperator <name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droptask', 1, 'sp_droptask SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droptask', 2, 'Removes a scheduled task.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droptask', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droptask', 4, 'sp_droptask {<name> | <loginname> | <id>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpalert', 1, 'sp_helpalert SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpalert', 2, 'Reports information about the alerts defined for the server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpalert', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpalert', 4, 'sp_helpalert [<having_name_like>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helphistory', 1, 'sp_helphistory SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helphistory', 2, 'Reports the history of one or more scheduled events, alerts, or tasks.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helphistory', 3, 'Some of the information in the systasks table is not displayed to users other')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helphistory', 4, 'than the system administrator.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helphistory', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helphistory', 6, 'sp_helphistory [, <taskname>] [, <taskid>] [, <eventid>] [, <messageid>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helphistory', 7, '     [, <severity>] [, <source>] [, <category>] [, <startdate>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helphistory', 8, '     [, <enddate>] [, <starttime>] [, <endtime>] [, <skipped>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helphistory', 9, '     [, oldestfirst] [, <mode>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpnotification', 1, 'sp_helpnotification SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpnotification', 2, 'Reports a list of notifications.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpnotification', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpnotification', 4, 'sp_helpnotification <object_type>, <name>, <enum_type>,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpnotification', 5, '     <notification_method> [, <target_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpoperator', 1, 'sp_helpoperator SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpoperator', 2, 'Reports information about the operators defined for the server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpoperator', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpoperator', 4, 'sp_helpoperator [<having_name_like>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helptask', 1, 'sp_helptask SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helptask', 2, 'Provides information about one or more tasks. Some of the information')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helptask', 3, 'in the systasks table is not displayed to users other than the system')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helptask', 4, 'administrator.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helptask', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helptask', 6, 'sp_helptask <taskname> [, <taskid>] [, <loginname>] [, <operatorname>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helptask', 7, '     [, <subsystem>] [, <mode>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_purgehistory', 1, 'sp_purgehistory SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_purgehistory', 2, 'Removes information from the history log.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_purgehistory', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_purgehistory', 4, 'sp_purgehistory [<taskname>] [, <taskid>] [, <eventid>] [, <messageid>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_purgehistory', 5, '     [, <severity>] [, <source>] [, <category>] [, <startdate>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_purgehistory', 6, '     [, <enddate>] [, <starttime>] [, <endtime>] [, <skipped>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_runtask', 1, 'sp_runtask SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_runtask', 2, 'Immediately executes a SQL Executive scheduled task either from a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_runtask', 4, 'command batch or from a user-defined stored procedure.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_runtask', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_runtask', 6, 'sp_runtask {''<task_name>'' | @task_id=}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatealert', 1, 'sp_updatealert SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatealert', 2, 'Updates information for an existing alert.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatealert', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatealert', 4, 'sp_updatealert <name> [, <new_name>] [, <enabled>] [, <message_id>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatealert', 5, '     [, <severity>] [, <delay_between_responses>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatealert', 6, '     [, <notification_message>] [, <include_event_description_in>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatealert', 7, '     [, <database_name>] [, <event_description_keyword>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatealert', 8, '     [, <task_name>] [, <occurrence_count>] [, <count_reset_date>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatealert', 9, '     [, <count_reset_time>] [, <last_occurrence_date>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatealert', 10, '     [, <last_occurrence_time>] [, <last_response_date>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatealert', 11, '     [, <last_response _time>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatenotification', 1, 'sp_updatenotification SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatenotification', 2, 'Updates the notification method of an alert notification.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatenotification', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatenotification', 4, 'sp_updatenotification <alert_name>, <operator_name>,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatenotification', 5, '     <notification_method>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updateoperator', 1, 'sp_updateoperator SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updateoperator', 2, 'Updates information about an operator.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updateoperator', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updateoperator', 4, 'sp_updateoperator <name> [, <new_name>] [, <enabled>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updateoperator', 5, '     [, <email_address>] [, <pager_number>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updateoperator', 6, '     [, <weekday_pager_start_time>] [, <weekday_pager_end_time>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updateoperator', 7, '     [, <saturday_pager_start_time>] [, <saturday_pager_end_time>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updateoperator', 8, '     [, <sunday_pager_start_time>] [, <sunday_pager_end_time>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updateoperator', 9, '     [, <pager_days>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 1, 'sp_updatetask SQL Executive Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 2, 'Updates information about a task.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 4, 'sp_updatetask {<currentname> | <id>} [, <name>] [, <subsystem>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 5, '     [, <server>] [, <username>] [, <databasename>] [, <enabled>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 6, '     [, <freqtype>] [, <freqinterval>] [, <freqsubtype>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 7, '     [, <freqsubinterval>] [, <freqrelativeinterval>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 8, '     [, <freqrecurrencefactor>] [, <activestartdate>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 9, '     [, <activeenddate>] [, <activestarttimeofday>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 10, '     [, <activeendtimeofday>] [, <nextrundate>] [, <nextruntime>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 11, '     [, <runpriority>] [, <emailoperatorname>] [, <retryattempts>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 12, '     [, <retrydelay>] [, <command>] [, <loghistcompletionlevel>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 13, '     [, <emailcompletionlevel>] [, <description>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 14, '     [, <tagadditionalinfo>] [, <tagobjectid>] [, <tagobjecttype>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_updatetask', 15, '     [,@cmdexecsuccesscode]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addalias', 1, 'sp_addalias System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addalias', 2, 'Maps one user to another in a database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addalias', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addalias', 4, 'sp_addalias <login_ID>, <username>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addextendedproc', 1, 'sp_addextendedproc System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addextendedproc', 2, 'Registers the name of a new extended stored procedure to SQL Server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addextendedproc', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addextendedproc', 4, 'sp_addextendedproc <function_name>, <dll_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addgroup', 1, 'sp_addgroup System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addgroup', 2, 'Creates a group in the current database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addgroup', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addgroup', 4, 'sp_addgroup <grpname>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addlogin', 1, 'sp_addlogin System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addlogin', 2, 'Creates a new SQL Server user by adding an entry to')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addlogin', 3, 'master.dbo.syslogins.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addlogin', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addlogin', 5, 'sp_addlogin <login_ID> [, <passwd> [, <defdb> [, <deflanguage>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addlogin', 6, '	[,login_suid]]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addmessage', 1, 'sp_addmessage System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addmessage', 2, 'Adds a new error message to the sysmessages table.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addmessage', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addmessage', 4, 'sp_addmessage <msg_id>, <severity>, ''<text of message>''')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addmessage', 5, '          [, <language> [, TRUE | FALSE [, REPLACE]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindsession', 1, 'sp_bindsession System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindsession', 2, 'Binds or unbinds a connection to other connections. A bound')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindsession', 3, 'connection allows two or more connections to participate in')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindsession', 4, 'the same transaction and share the transaction space until')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindsession', 5, 'a ROLLBACK or COMMIT TRANSACTION.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindsession', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindsession', 7, 'sp_bindsession {''<bindtoken>'' | ''NULL''}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addremotelogin', 1, 'sp_addremotelogin System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addremotelogin', 2, 'Adds a new remote login ID to master.dbo.sysremotelogins.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addremotelogin', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addremotelogin', 4, 'sp_addremotelogin <remoteserver> [, <login_ID> [, <remotename>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsegment', 1, 'sp_addsegment System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsegment', 2, 'Defines a segment on a database device in the current database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsegment', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addsegment', 4, 'sp_addsegment <segname>, <logical_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addserver', 1, 'sp_addserver System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addserver', 2, 'Defines a remote server or the name of the local server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addserver', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addserver', 4, 'sp_addserver <server_name> [, LOCAL]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtype', 1, 'sp_addtype System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtype', 2, 'Creates a user-defined datatype.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtype', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addtype', 4, 'sp_addtype <typename>, <phystype> [, <nulltype>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addumpdevice', 1, 'sp_addumpdevice System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addumpdevice', 2, 'Adds a dump device to SQL Server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addumpdevice', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addumpdevice', 4, 'sp_addumpdevice {''disk'' | ''diskette'' | ''tape''}, ''<logical_name>'',')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addumpdevice', 5, '     ''<physical_name>'' [, {{<cntrltype> [, noskip | skip')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addumpdevice', 6, '     [, <media_capacity>]]} |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_addumpdevice', 7, '     {@devstatus = {noskip | skip}}}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_adduser', 1, 'sp_adduser System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_adduser', 2, 'Adds a new user to the current database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_adduser', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_adduser', 4, 'sp_adduser <login_ID> [, <username> [, <grpname>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_altermessage', 1, 'sp_altermessage System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_altermessage', 2, 'Alters the state of a sysmessages error.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_altermessage', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_altermessage', 4, 'sp_altermessage <message_id>, WITH_LOG, {TRUE | FALSE}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindefault', 1, 'sp_bindefault System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindefault', 2, 'Binds a default to a column or to a user-defined datatype.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindefault', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindefault', 4, 'sp_bindefault <defname>, <objname> [, FUTUREONLY]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindrule', 1, 'sp_bindrule System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindrule', 2, 'Binds a rule to a column or to a user-defined datatype.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindrule', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_bindrule', 4, 'sp_bindrule <rulename>, <objname> [, FUTUREONLY]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_certify_removable', 1, 'sp_certify_removable System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_certify_removable', 2, 'Verifies that a database is configured properly for distribution on')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_certify_removable', 3, 'removable media. This procedure writes verification information to a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_certify_removable', 4, 'text file in the \LOG directory. The file is named according to the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_certify_removable', 5, 'following format:  CertifyR_[<dbname>].txt')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_certify_removable', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_certify_removable', 7, 'sp_certify_removable <dbname>[, AUTO]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changedbowner', 1, 'sp_changedbowner System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changedbowner', 2, 'Changes the owner of a database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changedbowner', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changedbowner', 4, 'sp_changedbowner <login_ID> [, TRUE]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changegroup', 1, 'sp_changegroup System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changegroup', 2, 'Changes a user''s group.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changegroup', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_changegroup', 4, 'sp_changegroup <grpname>, <username>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_change_users_logins', 1, 'sp_change_users_logins System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_change_users_logins', 2, 'Reestablishes foreign key relationships from the syslogins to sysusers')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_change_users_logins', 3, 'and sysalternates tables in cases where cross-server DUMP or LOAD')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_change_users_logins', 4, 'database activity has broken these relationships. Without reestablishing')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_change_users_logins', 5, 'relationships, orphan users may exist. It is suggested that you use this')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_change_users_logins', 6, 'stored procedure after running the LOAD DATABASE statement because')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_change_users_logins', 7, 'sp_change_users_login eliminates the need for manual updates for aliases or')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_change_users_logins', 8, 'alternate usernames.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_change_users_logins', 9, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_change_users_logins', 10, 'sp_change_users_login {Auto_Fix | Report | Update_One} [,<usernameorpattern>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_change_users_logins', 11, '	[,<loginname>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 1, 'sp_configure System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 2, 'Displays or changes configuration options. The following options can be modified')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 3, 'using sp_configure.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 4, '	affinity mask		[0-2147483647]		allow updates 		[0-1]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 5, '	backup buffer size   	[1-10]			backup threads 		[0-32]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 6, '	cursor threshold    	[-1-2147483647]		database size 		[2-10000]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 7, '	default language     	[0-9999]		default sortorder id 	[0-255]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 8, '	fill factor   		[[0-100]		free buffers 		[20-524288]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 9, '	hash buckets    	[4999-265003]		language in cache 	[3-100]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 10, '	LE threshold maximum    [2-500000]		LE threshold minimum 	[2-500000]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 11, '	LE threshold percent    [1-100]			locks 			[5000-2147483647]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 12, '	logwrite sleep (ms)    	[-1-500]		max async IO 		[1-255]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 13, '	max laywrite IO    	[1-255]			max text repl size	[0-2147483647]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 14, '	max worker threads 	[10-1024]		media retention    	[0-365]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 15, '	memory 			[1000-1048576]		nested triggers    	[0-1]	')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 16, '	network packet size 	[512-32767]		open databases     	[5-32767]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 17, '	open objects 		[100-2147483647] 	priority boost		[0-1]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 18, '	procedure cache 	[1-99]			RA cache hit limit    	[1-255]		')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 19, '	RA cache miss limit	[1-255] 		RA delay		[0-500]	')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 20, '	RA pre-fetches   	[1-1000]		RA slots per thread 	[1-255]	')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 21, '	RA worker threads   	[0-255]			recovery flags 		[0-1]			')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 22, '	recovery interval  	[1-32767]		remote access 		[[0-1]		')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 23, '	remote conn timeout    	[-1-32767]		remote login timeout 	[0-2147483647]	')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 24, '	remote proc trans   	[0-1]			remote query timeout 	[0-2147483647]	')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 25, '	remote sites		[0-256]			resource timeout		[5-2147483647]	')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 26, '	set working set size  	[0-1]   		show advanced options 	[0-1]	')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 27, '	SMP concurrency    	[-1-64]			sort pages 		[64-611]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 28, '	spin counter 		[1-2147483647]  	tempdb in ram(MB)  	[0-2044]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 29, '	time slice    		[50-1000]		user connections	[5-32767]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 30, '	user options		[0-4095]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 31, '	')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_configure', 32, 'sp_configure [''<config_name>'' [, <config_value>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_coalesce_fragments', 1, 'sp_coalesce_fragments System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_coalesce_fragments', 2, 'Deletes and updates rows in the sysusages system table and merges contiguous')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_coalesce_fragments', 3, 'fragments from the same segment and database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_coalesce_fragments', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_coalesce_fragments', 5, 'sp_coalesce_fragments')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_create_removable', 1, 'sp_create_removable System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_create_removable', 2, 'Creates a removable media database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_create_removable', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_create_removable', 4, 'sp_create_removable <dbname>, <syslogical>, ''<sysphysical>'', <syssize>,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_create_removable', 5, '     <loglogical>, ''<logphysical>'', <logsize>, <datalogical1>,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_create_removable', 6, '     ''<dataphysical1>'', <datasize1> [... , <datalogical16>,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_create_removable', 7, '     ''<dataphysical16>'', <datasize16>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dbinstall', 1, 'sp_dbinstall System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dbinstall', 2, 'Installs a database and its devices.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dbinstall', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dbinstall', 4, 'sp_dbinstall <database>, <logical_dev_name>, ''<physical_dev_name>'',')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dbinstall', 5, '     <size>, ''<devtype>'' [,''<location>'']')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dboption', 1, 'sp_dboption System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dboption', 2, 'Displays or changes database options.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dboption', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dboption', 4, 'sp_dboption [<dbname>, ''<optname>''] [,{TRUE | FALSE}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dbremove', 1, 'sp_dbremove System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dbremove', 2, 'Used to remove an installed database, and optionally, any devices to')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dbremove', 3, 'which it has exclusive use.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dbremove', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dbremove', 5, 'sp_dbremove <database>[, dropdev]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_defaultdb', 1, 'sp_defaultdb System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_defaultdb', 2, 'Changes a user''s default database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_defaultdb', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_defaultdb', 4, 'sp_defaultdb <login_ID>, <defdb>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_defaultlanguage', 1, 'sp_defaultlanguage System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_defaultlanguage', 2, 'Changes a user''s default language.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_defaultlanguage', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_defaultlanguage', 4, 'sp_defaultlanguage <login_ID> [, <language>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_depends', 1, 'sp_depends System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_depends', 2, 'Displays information about database object dependencies - the views and')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_depends', 3, 'procedures that depend on the specified table or view, and the tables')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_depends', 4, 'and views that are depended on by the specified view or procedure.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_depends', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_depends', 6, 'sp_depends <objname>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_devoption', 1, 'sp_devoption System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_devoption', 2, 'Displays or sets device status. Although primarily used on removable')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_devoption', 3, 'media devices, this procedure can be used for all devices.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_devoption', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_devoption', 5, 'sp_devoption [<devicename> [, <optname> {, TRUE | FALSE} [, OVERRIDE]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_diskdefault', 1, 'sp_diskdefault System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_diskdefault', 2, 'Sets a database device''s status to indicate whether the device can be')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_diskdefault', 3, 'used for database storage when the user does not specify a database')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_diskdefault', 4, 'device or specifies DEFAULT with the CREATE DATABASE or ALTER DATABASE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_diskdefault', 5, 'statements.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_diskdefault', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_diskdefault', 7, 'sp_diskdefault <database_device>, {defaulton | defaultoff}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropalias', 1, 'sp_dropalias System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropalias', 2, 'Removes the alias login ID identity that had been established by')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropalias', 3, 'sp_addalias.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropalias', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropalias', 5, 'sp_dropalias <login_ID>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropdevice', 1, 'sp_dropdevice System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropdevice', 2, 'Removes a SQL Server database device or dump device.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropdevice', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropdevice', 4, 'sp_dropdevice <logical_name> [, DELFILE]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropextendedproc', 1, 'sp_dropextendedproc System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropextendedproc', 2, 'Drops an extended stored procedure.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropextendedproc', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropextendedproc', 4, 'sp_dropextendedproc <function_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropgroup', 1, 'sp_dropgroup System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropgroup', 2, 'Removes a group from a database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropgroup', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropgroup', 4, 'sp_dropgroup <grpname>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droplanguage', 1, 'sp_droplanguage System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droplanguage', 2, 'Drops an alternate language from the server and removes its row from')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droplanguage', 3, 'master.dbo.syslogins.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droplanguage', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droplanguage', 5, 'sp_droplanguage <language> [, dropmessages]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droplogin', 1, 'sp_droplogin System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droplogin', 2, 'Removes a SQL Server login ID by deleting the user''s entry in')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droplogin', 3, 'master.dbo.syslogins.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droplogin', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droplogin', 5, 'sp_droplogin <login_ID>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropmessage', 1, 'sp_dropmessage System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropmessage', 2, 'Drops a specified error message from the sysmessages system table.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropmessage', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropmessage', 4, 'sp_dropmessage <msg_id>, [<language> | ''ALL'' ]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropremotelogin', 1, 'sp_dropremotelogin System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropremotelogin', 2, 'Removes a remote user login.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropremotelogin', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropremotelogin', 4, 'sp_dropremotelogin <remoteserver> [, <loginame> [, <remotename>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropsegment', 1, 'sp_dropsegment System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropsegment', 2, 'Drops a segment from a database or unmaps a segment from a database device.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropsegment', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropsegment', 4, 'sp_dropsegment <segname> [, <logical_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropserver', 1, 'sp_dropserver System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropserver', 2, 'Drops a server from the list of known servers, deleting the entry from')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropserver', 3, 'the master.dbo.sysservers table.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropserver', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropserver', 5, 'sp_dropserver <server_name> [, droplogins]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droptype', 1, 'sp_droptype System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droptype', 2, 'Deletes a user-defined datatype from systypes.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droptype', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_droptype', 4, 'sp_droptype <typename>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropuser', 1, 'sp_dropuser System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropuser', 2, 'Removes a user from the current database by deleting the entry from the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropuser', 3, 'current database''s sysusers table.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropuser', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropuser', 5, 'sp_dropuser <username>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_extendsegment', 1, 'sp_extendsegment System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_extendsegment', 2, 'Extends the range of a segment to another database device.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_extendsegment', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_extendsegment', 4, 'sp_extendsegment <segname>, <logical_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_activate_svr_db', 1, 'sp_fallback_activate_svr_db System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_activate_svr_db', 2, 'Activates fallback support for the specified fallback')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_activate_svr_db', 3, 'enrolled databases for a primary server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_activate_svr_db', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_activate_svr_db', 5, 'sp_fallback_activate_svr_db [<primary_svr_name>] [, <database>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_deactivate_svr_db', 1, 'sp_fallback_deactivate_svr_db System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_deactivate_svr_db', 2, 'Deactivates fallback suppport for the specified')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_deactivate_svr_db', 3, 'activated databases on a primary server. Deactivation')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_deactivate_svr_db', 4, 'leaves the databases enrolled.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_deactivate_svr_db', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_deactivate_svr_db', 6, 'sp_fallback_deactivate_svr_db [<primary_server_name>] [,<database>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_enroll_svr_db', 1, 'sp_fallback_enroll_svr_db System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_enroll_svr_db', 2, 'Enrolls a primary server''s database into the staging tables of a fallback')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_enroll_svr_db', 3, 'server, which prepares the server for future fallback support activation.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_enroll_svr_db', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_enroll_svr_db', 5, 'sp_fallback_enroll_svr_db {<fallback_svr_name>, <database>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_help', 1, 'sp_fallback_help System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_help', 2, 'Reports about enrollments and activations for fallback support and provides')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_help', 3, 'integrity checking.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_help', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_help', 5, 'sp_fallback_help [<primary_svr_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_permanent_svr', 1, 'sp_fallback_permanent_svr System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_permanent_svr', 2, 'Establishes the local fallback support server as the sole owner of')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_permanent_svr', 3, 'the active databases for an obsolete primary server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_permanent_svr', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_permanent_svr', 5, 'sp_fallback_permanent_svr {''<primary_server_name>'',1}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_upd_dev_drive', 1, 'sp_fallback_upd_dev_drive System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_upd_dev_drive', 2, 'Creates cross references to the drive letters used by the primary and')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_upd_dev_drive', 3, 'fallback support servers so both servers refer to the same physical drive.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_upd_dev_drive', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_upd_dev_drive', 5, 'sp_fallback_upd_dev_drive {''<primary_server_name>'', ''<primary_drive>'', ''<fallbac')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_withdraw_svr_db', 1, 'sp_fallback_withdraw_svr_db System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_withdraw_svr_db', 2, 'Erases the enrollment of inactive databases for a primary server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_withdraw_svr_db', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_fallback_withdraw_svr_db', 4, 'sp_fallback_withdraw_svr_db {''<primary_server_name>'' [,<database>]}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_getbindtoken', 1, 'sp_getbindtoken System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_getbindtoken', 2, 'Creates a bound connection context and returns a unique')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_getbindtoken', 3, 'identifier for the created context. This unique identifier')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_getbindtoken', 4, 'is referred to as a bind token. This system stored procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_getbindtoken', 5, 'returns a string representation to use as a token for a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_getbindtoken', 6, 'shared transaction between two clients.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_getbindtoken', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_getbindtoken', 6, 'sp_getbindtoken <return_value> OUTPUT [,@<for_xp_flag>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplogins', 1, 'sp_helplogins System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplogins', 2, 'Provides informaton about current logins and associated users.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplogins', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplogins', 4, 'sp_helplogins [<login_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_help', 1, 'sp_help System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_help', 2, 'Reports information about a database object (any object listed in the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_help', 3, 'sysobjects table) or about a SQL Server - supplied or user-defined')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_help', 4, 'datatype.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_help', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_help', 6, 'sp_help [<objname>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpconstraint', 1, 'sp_helpconstraint System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpconstraint', 2, 'Returns a list of all constraint types, their user-defined or system-')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpconstraint', 3, 'supplied name, and the columns on which they have been defined.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpconstraint', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpconstraint', 5, 'sp_helpconstraint <table_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpdb', 1, 'sp_helpdb System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpdb', 2, 'Reports information about a specified database or all databases.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpdb', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpdb', 4, 'sp_helpdb [<dbname>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpdevice', 1, 'sp_helpdevice System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpdevice', 2, 'Reports information about SQL Server database devices and dump devices.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpdevice', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpdevice', 4, 'sp_helpdevice [<logical_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpextendedproc', 1, 'sp_helpextendedproc System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpextendedproc', 2, 'Displays the currently defined extended stored procedures and the name')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpextendedproc', 3, 'of the dynamic-link library to which the function belongs.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpextendedproc', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpextendedproc', 5, 'sp_helpextendedproc [<function_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpgroup', 1, 'sp_helpgroup System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpgroup', 2, 'Reports information about a group or all groups in the current database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpgroup', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpgroup', 4, 'sp_helpgroup [<grpname>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpindex', 1, 'sp_helpindex System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpindex', 2, 'Reports information about the indexes on a table.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpindex', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpindex', 4, 'sp_helpindex <tabname>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplanguage', 1, 'sp_helplanguage System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplanguage', 2, 'Reports information about a particular alternate language or about all')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplanguage', 3, 'languages.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplanguage', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplanguage', 5, 'sp_helplanguage [<language>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplog', 1, 'sp_helplog System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplog', 2, 'Reports the name of the device that contains the first page of the log')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplog', 3, 'in the current database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplog', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplog', 5, 'sp_helplog')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpremotelogin', 1, 'sp_helpremotelogin System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpremotelogin', 2, 'Reports information about a particular remote server''s logins or about')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpremotelogin', 3, 'all remote servers'' logins.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpremotelogin', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpremotelogin', 5, 'sp_helpremotelogin [<remoteserver> [, <remotename>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helprotect', 1, 'sp_helprotect System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helprotect', 2, 'Reports permissions by database object for specific grantee, grantor or')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helprotect', 3, 'permissions.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helprotect', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helprotect', 5, 'sp_helprotect [<object_or_statement_name> [, <grantee_name> [, <grantor_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helprotect', 6, '		[, <permissions]]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsegment', 1, 'sp_helpsegment System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsegment', 2, 'Reports information about a particular segment or about all segments in')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsegment', 3, 'the current database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsegment', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsegment', 5, 'sp_helpsegment [<segname>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpserver', 1, 'sp_helpserver System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpserver', 2, 'Provides the server name, the server''s network name, the server''s replication')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpserver', 3, 'status, and the server''s identification number.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpserver', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpserver', 5, 'sp_helpserver [<server_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsort', 1, 'sp_helpsort System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsort', 2, 'Displays the SQL Server default sort order and character set.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsort', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsort', 4, 'sp_helpsort')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsql', 1, 'sp_helpsql System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsql', 2, 'Provides syntax for Transact-SQL statements, system procedures,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsql', 3, 'and other special topics.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsql', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpsql', 5, 'sp_helpsql [''<topic>'']')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helprevdatabase', 1, 'sp_helprevdatabase System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helprevdatabase', 2, 'Analyzes an existing database and creates a script that can')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helprevdatabase', 3, 'be used to replicate the database structure on another server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helprevdatabase', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helprevdatabase', 5, 'sp_helprevdatabase [<database>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpstartup', 1, 'sp_helpstartup System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpstartup', 2, 'Reports a listing of all auto-start stored procedures.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpstartup', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpstartup', 4, 'sp_helpstartup')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helptext', 1, 'sp_helptext System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helptext', 2, 'Prints the text of a rule, a default, or an unencrypted stored')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helptext', 3, 'procedure, trigger, or view.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helptext', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helptext', 5, 'sp_helptext <objname>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpuser', 1, 'sp_helpuser System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpuser', 2, 'Reports information about the users of a database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpuser', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helpuser', 4, 'sp_helpuser [<username>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplock', 1, 'sp_lock System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplock', 2, 'Reports information about locks.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplock', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_helplock', 4, 'sp_lock [<spid1> [, <spid2>]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_logdevice', 1, 'sp_logdevice System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_logdevice', 2, 'Puts the syslogs system table, which contains the transaction log, on a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_logdevice', 3, 'separate database device.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_logdevice', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_logdevice', 5, 'sp_logdevice <dbname>, <database_device>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makestartup', 1, 'sp_makestartup System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makestartup', 2, 'Sets a stored procedure for auto execution. Auto execution stored')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makestartup', 3, 'procedures are executed every time the server is started.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makestartup', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makestartup', 5, 'sp_makestartup <procedure_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_monitor', 1, 'sp_monitor System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_monitor', 2, 'Displays statistics about SQL Server.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_monitor', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_monitor', 4, 'sp_monitor')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_password', 1, 'sp_password System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_password', 2, 'Adds or changes a password for a SQL Server login ID.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_password', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_password', 4, 'sp_password <old>, <new> [, <login_ID>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_placeobject', 1, 'sp_placeobject System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_placeobject', 2, 'Puts future space allocations for a table or index on a particular')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_placeobject', 3, 'segment.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_placeobject', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_placeobject', 5, 'sp_placeobject <segname>, <objname>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_processmail', 1, 'sp_processmail System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_processmail', 2, 'Uses extended stored procedures (xp_findnextmsg, xp_readmail, and')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_processmail', 3, 'xp_deletemail) to process incoming mail messages (expected to be only a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_processmail', 4, 'single query) from the inbox for SQL Server. It uses the xp_sendmail')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_processmail', 5, 'extended stored procedure to return the results set back to the message')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_processmail', 6, 'sender.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_processmail', 7, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_processmail', 8, 'sp_processmail [@subject = <subject>] [[,] @filetype = <filetype>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_processmail', 9, '     [[,] @separator = <separator>] [[,] @set_user = <user>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_processmail', 10, '     [[,] @dbuse = <dbname>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_recompile', 1, 'sp_recompile System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_recompile', 2, 'Causes each stored procedure and trigger that uses the specified table')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_recompile', 3, 'to be recompiled the next time the stored procedure and triggers are')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_recompile', 4, 'run.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_recompile', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_recompile', 6, 'sp_recompile <tabname>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_remoteoption', 1, 'sp_remoteoption System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_remoteoption', 2, 'Displays or changes remote login options.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_remoteoption', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_remoteoption', 4, 'sp_remoteoption [<remoteserver>, <loginame>, <remotename>,')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_remoteoption', 5, '     <optname>, {TRUE | FALSE}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_rename', 1, 'sp_rename System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_rename', 2, 'Changes the name of a user-created object in the current database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_rename', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_rename', 4, 'sp_rename <objname>, <newname> [, COLUMN | INDEX ]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_renamedb', 1, 'sp_renamedb System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_renamedb', 2, 'Changes the name of a database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_renamedb', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_renamedb', 4, 'sp_renamedb <oldname>, <newname>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_serveroption', 1, 'sp_serveroption System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_serveroption', 2, 'Sets server options.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_serveroption', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_serveroption', 4, 'sp_serveroption [<server_name>, <optname>, {TRUE | FALSE}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_setlangalias', 1, 'sp_setlangalias System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_setlangalias', 2, 'Assigns or changes the alias for an alternate language.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_setlangalias', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_setlangalias', 4, 'sp_setlangalias <language>, <alias>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_spaceused', 1, 'sp_spaceused System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_spaceused', 2, 'Displays the number of rows, the disk space reserved, and the disk space')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_spaceused', 3, 'used by a table in a database, or displaces the disk space reserved and')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_spaceused', 4, 'used by an entire database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_spaceused', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_spaceused', 6, 'sp_spaceused [<objname>] [[,] @updateusage = {TRUE | FALSE}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unbindefault', 1, 'sp_unbindefault System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unbindefault', 2, 'Unbinds (removes) a default from a column or from a user-defined')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unbindefault', 3, 'datatype in the current database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unbindefault', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unbindefault', 5, 'sp_unbindefault <objname> [, FUTUREONLY]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unbindrule', 1, 'sp_unbindrule System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unbindrule', 2, 'Unbinds a rule from a column or a user-defined datatype in the current')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unbindrule', 3, 'database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unbindrule', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unbindrule', 5, 'sp_unbindrule <objname> [, FUTUREONLY]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unmakestartup', 1, 'sp_unmakestartup System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unmakestartup', 2, 'Discontinues auto execution of the stored procedure.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unmakestartup', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_unmakestartup', 4, 'sp_unmakestartup <procedure_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_who', 1, 'sp_who System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_who', 2, 'Provides information about current SQL Server users and processes. The informati')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_who', 3, 'can be filtered to return only those processes that are not idle.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_who', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_who', 5, 'sp_who [<login_name> | ''<spid>'' | <active>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropwebtask', 1, 'sp_dropwebtask Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropwebtask', 2, 'Deletes a previously defined web task. The task to be deleted is')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropwebtask', 3, 'identified by the output filename, by the procedure name, or by both')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropwebtask', 4, 'paramters.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropwebtask', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropwebtask', 6, 'sp_dropwebtask {@<procname> = <procname> | @<outputfile> = <outputfile> |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_dropwebtask', 7, '@<procname> = <procname>, @<outputfile> = <outputfile>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 1, 'sp_makewebtask System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 2, 'Creates a task that produces an HTML document. The HTML document contains')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 3, 'data returned by executed queries.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 5, 'sp_makewebtask{@outputfile = ''<outputfile>'', @query = ''<query>''}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 6, '[, @fixedfont = <fixedfont>][, @bold = <bold>][, @italic = <italic>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 7, '[, @colheaders = <colheaders>][,@lastupdated = <lastupdated>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 8, '  [,@HTMLheader = <HTMLheader>][, @username = <username>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 9, '[,@dbname = <dbname>][,@templatefile = ''<templatefile>'']')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 10, '[, @webpagetitle = ''<webpagetitle>''][, @resultstitle = ''<resultstitle>'']')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 11, '[,[@URL = ''<URL>'',@reftext = ''<reftext>''] | [@table_urls = <table_urls>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 12, ',@url_query = ''<url_query>'']][,@whentype = <whentype>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 13, '[,@targetdate = <targetdate>][,@targettime = <targettime>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 14, '[,@dayflags = <dayflags>][, @numunits = <numunits>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 15, '[,@unittype = <unittype>][,@procname = <procname>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 16, '[,@maketask = <maketask>][,@rowcount = <rowcnt>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 17, ' [,@taborder = <taborder>][,@singlerow = <singlerow>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_makewebtask', 18, '[,@blobfmt = <blobfmt>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_runwebtask', 1, 'sp_runwebtask System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_runwebtask', 2, 'Executes a previously defined Web task and generates the HTML document.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_runwebtask', 3, 'The task to run is identified by the output filename, by the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_runwebtask', 4, 'procedure name, or by both parameters.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_runwebtask', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_runwebtask', 6, 'sp_runwebtask {@procname = <procname> | @outputfile = <outputfile> |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_runwebtask', 7, ' @procname = <procname>, @outputfile = <outputfile>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_rename', 1, 'sp_rename System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_rename', 2, 'Changes the name of a user-created object in the current database.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_rename', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_rename', 4, 'sp_rename {<oldname>, <newname> [,COLUMN | INDEX | OBJECT | USERDATATYPE]}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_setnetname', 1, 'sp_setnetname System Stored Procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_setnetname', 2, 'Sets the network names in sysservers to their actual network')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_setnetname', 3, 'machine names for remote computers running SQL Server. Names')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_setnetname', 4, 'can include hyphens and other non-alphabetic characters. This')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_setnetname', 5, 'procedure can be used to enable execution of remote stored procedure')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_setnetname', 6, ' calls to machines that have network names containing invalid SQL')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_setnetname', 7, 'Server identifiers.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_setnetname', 8, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('sp_setnetname', 9, 'sp_setnetname @<server> [= ''<server>''], @<netname> [= ''<netname>'']')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('READTEXT', 1, 'READTEXT Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('READTEXT', 2, 'Reads text and image values, starting from a specified offset and')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('READTEXT', 3, 'reading a specified number of bytes.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('READTEXT', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('READTEXT', 5, 'READTEXT [[<database>.]<owner>.]<table_name>.<column_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('READTEXT', 6, '     <text_ptr> <offset> <size> [HOLDLOCK]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATETEXT', 1, 'UPDATETEXT Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATETEXT', 2, 'Updates an existing text or image field.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATETEXT', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATETEXT', 4, 'UPDATETEXT [[<database>.]<owner>.]<table_name>.<dest_column_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATETEXT', 5, '     <dest_text_ptr> {NULL | <insert_offset>} {NULL | <delete_length>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATETEXT', 6, '     [WITH LOG]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATETEXT', 7, '     [<inserted_data> |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATETEXT', 8, '     [{[<database>.]<owner>.]<table_name>.<src_column_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATETEXT', 9, '          <src_text_ptr>}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WRITETEXT', 1, 'WRITETEXT Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WRITETEXT', 2, 'Permits nonlogged, interactive updating of an existing text or image')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WRITETEXT', 3, 'field. This statement completely overwrites any existing data in the')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WRITETEXT', 4, 'column it affects.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WRITETEXT', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WRITETEXT', 6, 'WRITETEXT [[<database>.]<owner>.]<table_name>.<column_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WRITETEXT', 7, '     <text_ptr> [WITH LOG] <data>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRANSACTIONS', 1, 'Transactions')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRANSACTIONS', 2, 'A transaction is a single unit of work. An explicit transaction is a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRANSACTIONS', 3, 'grouping of SQL statements surrounded by the transaction delimiters:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRANSACTIONS', 4, 'BEGIN TRANSACTION, COMMIT TRANSACTION, and optionally, one or more of')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRANSACTIONS', 5, 'the following statements:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRANSACTIONS', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRANSACTIONS', 7, '     BEGIN TRANSACTION')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRANSACTIONS', 8, '     COMMIT TRANSACTION')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRANSACTIONS', 9, '     ROLLBACK TRANSACTION')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRANSACTIONS', 10, '     SAVE TRANSACTION')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN TRANSACTION', 1, 'BEGIN TRANSACTION Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN TRANSACTION', 2, 'Marks the starting point of a user-specified transaction.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN TRANSACTION', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('BEGIN TRANSACTION', 4, 'BEGIN TRANsaction [<transaction_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('COMMIT TRANSACTION', 1, 'COMMIT TRANSACTION Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('COMMIT TRANSACTION', 2, 'Marks the end of a user-defined transaction.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('COMMIT TRANSACTION', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('COMMIT TRANSACTION', 4, 'COMMIT TRANsaction [<transaction_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ROLLBACK TRANSACTION', 1, 'ROLLBACK TRANSACTION Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ROLLBACK TRANSACTION', 2, 'Rolls back a user-specified transaction to the last savepoint inside a')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ROLLBACK TRANSACTION', 3, 'transaction or to the beginning of a transaction.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ROLLBACK TRANSACTION', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('ROLLBACK TRANSACTION', 5, 'ROLLBACK TRANsaction [<transaction_name> | <savepoint_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SAVE TRANSACTION', 1, 'SAVE TRANSACTION Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SAVE TRANSACTION', 2, 'Sets a savepoint within a transaction.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SAVE TRANSACTION', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('SAVE TRANSACTION', 4, 'SAVE TRANsaction <savepoint_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRUNCATE TABLE', 1, 'TRUNCATE TABLE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRUNCATE TABLE', 2, 'Removes all rows from a table without logging the individual row')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRUNCATE TABLE', 3, 'deletes. This allows TRUNCATE TABLE to be efficient and quick, but')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRUNCATE TABLE', 4, 'unrecoverable.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRUNCATE TABLE', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('TRUNCATE TABLE', 6, 'TRUNCATE TABLE [[<database>.]<owner>.]<table_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 1, 'UNION Operator')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 2, 'Combines the results of two or more queries into a single results set')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 3, 'consisting of all the rows belonging to any subset of the queries or to')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 4, 'all queries in the union.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 6, 'SELECT <select_list>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 7, '     [<INTO clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 8, '     [<FROM clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 9, '     [<WHERE clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 10, '     [<GROUP BY clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 11, '     [<HAVING clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 12, '[UNION [ALL]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 13, 'SELECT <select_list>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 14, '     [<FROM clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 15, '     [<WHERE clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 16, '     [<GROUP BY clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 17, '     [<HAVING clause>]...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 18, '[<ORDER BY clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UNION', 19, '[<COMPUTE clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 1, 'UPDATE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 2, 'Changes data in existing rows, either by adding new data or by modifying')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 3, 'existing data.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 5, 'UPDATE {<table_name> | <view_name>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 6, 'SET [{<table_name> | <view_name>}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 7, '     {<column_name> | <column_list> |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 8, '     <variable_list> |')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 9, '     <variable_and_column_list>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 10, '          [[, {<column_listn>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 11, '               | <variable_listn>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 12, '               | <variable_and_column_listn>}...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 13, '[WHERE clause]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 14, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 15, 'Transact-SQL extension syntax:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 16, 'UPDATE {<table_name> | <view_name>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 17, 'SET [{<table_name> | <view_name>}]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 18, '     {<column_list>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 19, '     | <variable_list>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 20, '     | <variable_and_column_list>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 21, '          [, {<column_list2>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 22, '               | <variable_list2>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 23, '               | <variable_and_column_list2>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 24, '               ...     [, {<column_listN>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 25, '                         | <variable_listN>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 26, '                         | <variable_and_column_listN>}]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 27, '[FROM {<table_name> | <view_name>}[(<optimizer_hints>)]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 28, '     [, {<table_name2> | <view_name2>}[(<optimizer_hints>)]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 29, '          [..., {<table_name16> | <view_name16>}[(<optimizer_hints>)]]]]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 30, '[<WHERE clause>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 31, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 32, 'where')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 33, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 34, '<table_name> | <view_name> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 35, '     [[<database_name>.]<owner>.]{<table_name> | <view_name>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 36, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 37, '<column_list> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 38, '     <column_name> = {<expression> | DEFAULT | NULL}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 39, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 40, '<variable_list> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 41, '     <variable_name> = {<expression> | NULL}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 42, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 43, '<variable_and_column_list> =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 44, '     <variable_name> = <column_name> = {<expression> | NULL}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 45, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 46, 'WHERE clause =')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE', 47, '     WHERE {<search_conditions> | CURRENT OF <cursor_name>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE STATISTICS', 1, 'UPDATE STATISTICS Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE STATISTICS', 2, 'Updates information about the distribution of key values in specified')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE STATISTICS', 3, 'indexes.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE STATISTICS', 4, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('UPDATE STATISTICS', 5, 'UPDATE STATISTICS [[<database>.]<owner>.]<table_name> [<index_name>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('USE', 1, 'USE Statement')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('USE', 2, 'Changes the database context.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('USE', 3, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('USE', 4, 'USE <database_name>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 1, 'Variables')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 2, 'Local variables are declared in the body of a batch or procedure with')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 3, 'the DECLARE statement and given values with a SELECT statement. Local')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 4, 'variables are often used in a batch or procedure as counters for WHILE')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 5, 'loops or for IF...ELSE blocks.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 6, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 7, 'Variable declaration:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 8, '     DECLARE @<variable_name> <datatype>')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 9, '          [, @<variable_name> <datatype>...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 10, 'Variable assignment:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 11, '     SELECT @<variable> = {<expression> | <select_statement>}')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 12, '          [, @<variable> = {<expression> | <select_statement>}...]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 13, '     [FROM <table_list>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 14, '     [WHERE <search_conditions>]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 15, '     [GROUP BY clause]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 16, '     [HAVING clause]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('VARIABLES', 17, '     [ORDER BY clause]')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 1, 'Wildcard Characters')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 2, 'Wildcard characters are used with the LIKE keyword to represent any')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 3, 'character in a string when searching for a char, varchar, or datetime')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 4, 'value.')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 5, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 6, '<expression> [NOT] LIKE ''<string>''')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 7, '')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 8, 'The string can include these wildcard characters:')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 9, '%                Any string of zero or more characters')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 10, '_ (underscore)   Any single character')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 11, '[ ]              Any single character within the specified range')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 12, '                  ([a-f]) or set ([abcdef])')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 13, '[^]              Any single character not within the specified range')
GO
INSERT master..helpsql(command, ordering, helptext) VALUES ('WILDCARDS', 14, '                  ([^a-f]) or set ([^abcdef])')
GO
